@@ -1,7 +1,7 @@
 /*
  * c_devnull - a custom function that does nothing
  *
- * Copyright (C) 1999-2004,2021  Landon Curt Noll
+ * Copyright (C) 1999-2004,2021,2023  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -25,21 +25,32 @@
  */
 
 
+/*
+ * ISO C requires a translation unit to contain at least one declaration,
+ * so we declare a global variable whose value is based on if CUSTOM is defined.
+ */
+#if defined(CUSTOM)
+int c_devnull_allowed = 1;	/* CUSTOM defined */
+#else /* CUSTOM */
+int c_devnull_allowed = 0;	/* CUSTOM undefined */
+#endif /* CUSTOM */
+
+
 #if defined(CUSTOM)
 
-#include "have_unistd.h"
+#include "../have_unistd.h"
 #if defined(HAVE_UNISTD_H)
 #include <unistd.h>
 #endif
 
-#include "have_const.h"
-#include "value.h"
-#include "custom.h"
+#include "../have_const.h"
+#include "../value.h"
+#include "../custom.h"
 
-#include "have_unused.h"
+#include "../have_unused.h"
 
 
-#include "banned.h"	/* include after system header <> includes */
+#include "../banned.h"	/* include after system header <> includes */
 
 
 /*
