@@ -1,7 +1,7 @@
 /*
  * c_pmodm127 - calculate q mod 2^(2^127-1)
  *
- * Copyright (C) 2004-2007,2021,2022  Landon Curt Noll
+ * Copyright (C) 2004-2007,2021-2023  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -24,20 +24,31 @@
  */
 
 
+/*
+ * ISO C requires a translation unit to contain at least one declaration,
+ * so we declare a global variable whose value is based on if CUSTOM is defined.
+ */
+#if defined(CUSTOM)
+int c_pmodm127_allowed = 1;	/* CUSTOM defined */
+#else /* CUSTOM */
+int c_pmodm127_allowed = 0;	/* CUSTOM undefined */
+#endif /* CUSTOM */
+
+
 #if defined(CUSTOM)
 
 #include <stdio.h>
 
-#include "have_const.h"
-#include "value.h"
-#include "custom.h"
-#include "zmath.h"
+#include "../have_const.h"
+#include "../value.h"
+#include "../custom.h"
+#include "../zmath.h"
 
-#include "have_unused.h"
+#include "../have_unused.h"
 
 
-#include "attribute.h"
-#include "banned.h"	/* include after system header <> includes */
+#include "../errtbl.h"
+#include "../banned.h"	/* include after system header <> includes */
 
 
 /* 2^255 */
@@ -59,7 +70,7 @@ ZVALUE p255 = {
 
 /* static declarations */
 S_FUNC void zmod5_or_zmod(ZVALUE *zp);
-STATIC BOOL havelastmod = FALSE;
+STATIC bool havelastmod = false;
 STATIC ZVALUE lastmod[1];
 STATIC ZVALUE lastmodinv[1];
 
@@ -111,14 +122,14 @@ c_pmodm127(char *UNUSED(name), int UNUSED(count), VALUE **vals)
 	if (havelastmod && zcmp(q, *lastmod)) {
 		zfree(*lastmod);
 		zfree(*lastmodinv);
-		havelastmod = FALSE;
+		havelastmod = false;
 	}
 	if (!havelastmod) {
 		zcopy(q, lastmod);
 		zbitvalue(2 * q.len * BASEB, &temp);
 		zquo(temp, q, lastmodinv, 0);
 		zfree(temp);
-		havelastmod = TRUE;
+		havelastmod = true;
 	}
 
 	/*
