@@ -1,7 +1,7 @@
 /*
  * c_pzasusb8 - print numerator as a string of USB8s
  *
- * Copyright (C) 1999-2004,2021,2022  Ernest Bowen
+ * Copyright (C) 1999-2004,2021-2023  Ernest Bowen
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -24,20 +24,31 @@
  */
 
 
+/*
+ * ISO C requires a translation unit to contain at least one declaration,
+ * so we declare a global variable whose value is based on if CUSTOM is defined.
+ */
+#if defined(CUSTOM)
+int c_pzasusb8_allowed = 1;	/* CUSTOM defined */
+#else /* CUSTOM */
+int c_pzasusb8_allowed = 0;	/* CUSTOM undefined */
+#endif /* CUSTOM */
+
+
 #if defined(CUSTOM)
 
 #include <stdio.h>
 
-#include "have_const.h"
-#include "value.h"
-#include "custom.h"
-#include "zmath.h"
+#include "../have_const.h"
+#include "../value.h"
+#include "../custom.h"
+#include "../zmath.h"
 
-#include "have_unused.h"
+#include "../have_unused.h"
 
 
-#include "attribute.h"
-#include "banned.h"	/* include after system header <> includes */
+#include "../errtbl.h"
+#include "../banned.h"	/* include after system header <> includes */
 
 
 /*
