@@ -1,7 +1,7 @@
 /*
  * custtbl - custom interface table
  *
- * Copyright (C) 1999-2007,2021  Landon Curt Noll
+ * Copyright (C) 1999-2007,2021,2023  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -24,19 +24,38 @@
  * Share and enjoy!  :-)	http://www.isthe.com/chongo/tech/comp/calc/
  */
 
+
 #include <unistd.h>
 
-#include "have_const.h"
-#include "value.h"
-#include "custom.h"
+#include "../have_const.h"
+#include "../value.h"
+#include "../custom.h"
 
 
-#include "banned.h"	/* include after system header <> includes */
+#include "../errtbl.h"
+#include "../banned.h"	/* include after system header <> includes */
 
 
 /*
- * NOTE: See the file CUSTOM for instructions on how to add
- *	 custom functions.
+ * custom_compiled - determine if custom functions are compiled into libcustcalc
+ *
+ * returns:
+s*	true  ==> libcustcalc was compiled with CUSTOM defined
+ *	false ==> libcustcalc was compiled with CUSTOM undefined
+ */
+E_FUNC bool
+custom_compiled(void)
+{
+#if defined(CUSTOM)
+	return true;
+#else /* CUSTOM */
+	return false;
+#endif /* CUSTOM */
+}
+
+
+/*
+ * NOTE: See the file HOW_TO_ADD for instructions on how to add custom functions.
  */
 
 
