@@ -38,13 +38,17 @@
  *		undefined ==> do not or cannot call getprid()
  */
 
-
+#include <stdio.h>
 #include <sys/types.h>
 #include "have_unistd.h"
 #if defined(HAVE_UNISTD_H)
 #include <unistd.h>
 #endif
 
+
+#include "banned.h"	/* include after system header <> includes */
+
+
 int
 main(void)
 {
