@@ -1,7 +1,7 @@
 /*
  * qfunc - extended precision rational arithmetic non-primitive functions
  *
- * Copyright (C) 1999-2007,2021,2022  David I. Bell and Ernest Bowen
+ * Copyright (C) 1999-2007,2021-2023  David I. Bell and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -31,7 +31,7 @@
 #include "prime.h"
 
 
-#include "attribute.h"
+#include "errtbl.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -43,6 +43,28 @@ STATIC long E_num;
 
 #define QALLOCNUM 64
 
+
+/*
+ * check_epsilon - verify that 0 < epsilon < 1
+ *
+ * given:
+ *	q	epsilon or eps argument
+ *
+ * returns:
+ *	false	q is NULL or q <= 0 or q >= 1
+ *	true	0 < q < 1
+ */
+bool
+check_epsilon(NUMBER *q)
+{
+        /* verify that 0 < epsilon < 1 */
+        if (q == NULL || qisneg(q) || qiszero(q) || qisone(q) || qreli(q, 1) > 0) {
+		return false;
+	}
+	return true;
+}
+
+
 /*
  * Set the default epsilon for approximate calculations.
  * This must be greater than zero.
@@ -55,10 +77,18 @@ setepsilon(NUMBER *q)
 {
 	NUMBER *old;
 
-	if (qisneg(q) || qiszero(q)) {
-		math_error("Epsilon value must be greater than zero");
+	/*
+	 * firewall
+	 */
+	if (q == NULL) {
+		math_error("q is NULL for %s", __func__);
 		not_reached();
 	}
+	if (check_epsilon(q) == false) {
+		math_error("Invalid value for epsilon: must be: 0 < epsilon < 1");
+		not_reached();
+	}
+
 	old = conf->epsilon;
 	conf->epsilonprec = qprecision(q);
 	conf->epsilon = qlink(q);
@@ -112,7 +142,7 @@ qminv(NUMBER *q1, NUMBER *q2)
 	r = qalloc();
 	if (s) {
 		zfree(z1);
-		z2.sign = TRUE;
+		z2.sign = true;
 		r->num = z2;
 		return r;
 	}
@@ -168,7 +198,7 @@ qpowermod(NUMBER *q1, NUMBER *q2, NUMBER *q3)
 	r = qalloc();
 	if (s) {
 		zfree(z1);
-		z2.sign = TRUE;
+		z2.sign = true;
 		r->num = z2;
 		return r;
 	}
@@ -187,7 +217,7 @@ NUMBER *
 qpowi(NUMBER *q1, NUMBER *q2)
 {
 	register NUMBER *r;
-	BOOL invert, sign;
+	bool invert, sign;
 	ZVALUE num, zden, z2;
 
 	if (qisfrac(q2)) {
@@ -263,7 +293,7 @@ qhypot(NUMBER *q1, NUMBER *q2, NUMBER *epsilon)
 	tmp3 = qqadd(tmp1, tmp2);
 	qfree(tmp1);
 	qfree(tmp2);
-	tmp1 = qsqrt(tmp3, epsilon, 24L);
+	tmp1 = qsqrt(tmp3, epsilon, conf->triground);
 	qfree(tmp3);
 	return tmp1;
 }
@@ -275,13 +305,13 @@ qhypot(NUMBER *q1, NUMBER *q2, NUMBER *epsilon)
  * If the wantneg flag is nonzero, then negative square root is returned.
  */
 NUMBER *
-qlegtoleg(NUMBER *q, NUMBER *epsilon, BOOL wantneg)
+qlegtoleg(NUMBER *q, NUMBER *epsilon, bool wantneg)
 {
 	NUMBER *res, *qtmp1, *qtmp2;
 	ZVALUE num;
 
 	if (qiszero(epsilon)) {
-		math_error("Zero epsilon value for legtoleg");
+		math_error("Zero epsilon value for ltol");
 		not_reached();
 	}
 	if (qisunit(q))
@@ -294,13 +324,13 @@ qlegtoleg(NUMBER *q, NUMBER *epsilon, BOOL wantneg)
 	num = q->num;
 	num.sign = 0;
 	if (zrel(num, q->den) >= 0) {
-		math_error("Leg too large in legtoleg");
+		math_error("Leg too large for ltol");
 		not_reached();
 	}
 	qtmp1 = qsquare(q);
 	qtmp2 = qsub(&_qone_, qtmp1);
 	qfree(qtmp1);
-	res = qsqrt(qtmp2, epsilon, 24L);
+	res = qsqrt(qtmp2, epsilon, conf->triground);
 	qfree(qtmp2);
 	if (wantneg) {
 		qtmp1 = qneg(res);
@@ -329,7 +359,7 @@ qsqrt(NUMBER *q1, NUMBER *epsilon, long rnd)
 	int sign;
 
 	if (qisneg(q1)) {
-		math_error("Square root of negative number");
+		math_error("Square root of negative number for qsqrt");
 		not_reached();
 	}
 	if (qiszero(q1))
@@ -435,7 +465,7 @@ qisqrt(NUMBER *q)
 	ZVALUE tmp;
 
 	if (qisneg(q)) {
-		math_error("Square root of negative number");
+		math_error("Square root of negative number for isqrt");
 		not_reached();
 	}
 	if (qiszero(q))
@@ -454,10 +484,10 @@ qisqrt(NUMBER *q)
 /*
  * Return whether or not a number is an exact square.
  */
-BOOL
+bool
 qissquare(NUMBER *q)
 {
-	BOOL flag;
+	bool flag;
 
 	flag = zissquare(q->num);
 	if (qisint(q) || !flag)
@@ -765,18 +795,18 @@ qdigit(NUMBER *q, ZVALUE dpos, ZVALUE base)
  * bit position.  Negative bit positions indicate bits to the right of the
  * binary decimal point.  Examples: qdigit(17.1, 0) = 1, qdigit(17.1, -1) = 0.
  */
-BOOL
+bool
 qisset(NUMBER *q, long n)
 {
 	NUMBER *qtmp1, *qtmp2;
 	ZVALUE ztmp;
-	BOOL res;
+	bool res;
 
 	/*
 	 * Zero number or negative bit position place of integer is trivial.
 	 */
 	if (qiszero(q) || (qisint(q) && (n < 0)))
-		return FALSE;
+		return false;
 	/*
 	 * For non-negative bit positions, answer is easy.
 	 */
@@ -1337,10 +1367,10 @@ qcfappr(NUMBER *q, NUMBER *epsilon, long rnd)
 	ZVALUE tmp1, tmp2, tmp3, tmp4;
 	ZVALUE denbnd;
 	ZVALUE f, g, k;
-	BOOL esign;
+	bool esign;
 	int s;
-	BOOL bnddencase;
-	BOOL useold = FALSE;
+	bool bnddencase;
+	bool useold = false;
 
 	if (qiszero(epsilon) || qisint(q))
 		return qlink(q);
@@ -1416,7 +1446,7 @@ qcfappr(NUMBER *q, NUMBER *epsilon, long rnd)
 	}
 	if (bnddencase) {
 		if (s > 0) {
-			useold = TRUE;
+			useold = true;
 		} else {
 			zsub(zden, denbnd, &tmp1);
 			zquo(tmp1, oldden, &k, 1);
@@ -1829,14 +1859,14 @@ qplaces(NUMBER *q, ZVALUE base)
 
 /*
  * Perform a probabilistic primality test (algorithm P in Knuth).
- * Returns FALSE if definitely not prime, or TRUE if probably prime.
+ * Returns false if definitely not prime, or true if probably prime.
  *
  * The absolute value of the 2nd arg determines how many times
  * to check for primality.  If 2nd arg < 0, then the trivial
  * check is omitted.  The 3rd arg determines how tests to
  * initially skip.
  */
-BOOL
+bool
 qprimetest(NUMBER *q1, NUMBER *q2, NUMBER *q3)
 {
 	if (qisfrac(q1) || qisfrac(q2) || qisfrac(q3)) {
@@ -1849,3 +1879,90 @@ qprimetest(NUMBER *q1, NUMBER *q2, NUMBER *q3)
 	}
 	return zprimetest(q1->num, ztoi(q2->num), q3->num);
 }
+
+
+/*
+ * test if a number is an integer power of 2
+ *
+ * given:
+ *	q	value to check if it is a power of 2
+ *	qlog2	when q is an integer power of 2 (return true), set to log base 2 of q
+ *		when q is NOT an integer power of 2 (return false), *qlog2 is not set
+ *
+ * returns:
+ *	true	q is a power of 2
+ *	false	q is not a power of 2
+ */
+bool
+qispowerof2(NUMBER *q, NUMBER **qlog2)
+{
+	FULL log2;		/* base 2 logarithm as a ZVALUE */
+
+	/* firewall */
+	if (q == NULL) {
+		math_error("%s: q is NULL", __func__);
+		not_reached();
+	}
+	if (qlog2 == NULL) {
+		math_error("%s: qlog2 is NULL", __func__);
+		not_reached();
+	}
+	if (*qlog2 == NULL) {
+		math_error("%s: *qlog2 is NULL", __func__);
+		not_reached();
+	}
+
+	/* zero and negative values are never integer powers of 2 */
+	if (qiszero(q) || qisneg(q)) {
+		/* leave *qlog2 untouched and return false */
+		return false;
+	}
+
+	/*
+	 * case: q>0 is an integer
+	 */
+	if (qisint(q)) {
+
+		/*
+		 * check if q is an integer power of 2
+		 */
+		if (zispowerof2(q->num, &log2)) {
+
+			/*
+			 * case: q is an integer power of 2
+			 *
+			 * Set *qlog2 to base 2 logarithm of q and return true.
+			 */
+			*qlog2 = utoq(log2);
+			return true;
+		}
+
+	/*
+	 * case: q>0 is 1 over an integer
+	 */
+	} else if (qisreciprocal(q)) {
+
+		/*
+		 * check if q is 1 over an integer power of 2
+		 */
+		if (zispowerof2(q->den, &log2)) {
+
+			/*
+			 * case: q>0 is an integer power of 2
+			 *
+			 * Set *qlog2 to base 2 logarithm of q, which will be a negative value,
+			 * and return true.
+			 */
+			*qlog2 = utoq(log2);
+			(*qlog2)->num.sign = !(*qlog2)->num.sign;		/* set *qlog2 to -log2 */
+			return true;
+		}
+	}
+
+	/*
+	 * q is not an integer power of 2
+	 *
+	 * Leave *qlog2 untouched and return false.
+	 */
+	return false;
+}
