@@ -1,7 +1,7 @@
 /*
  * qmath - declarations for extended precision rational arithmetic
  *
- * Copyright (C) 1999-2007,2014,2021  David I. Bell
+ * Copyright (C) 1999-2007,2014,2021,2023  David I. Bell and Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -68,7 +68,7 @@ E_FUNC void qfreenum(NUMBER *q);
 E_FUNC void qprintnum(NUMBER *q, int mode, LEN outdigits);
 E_FUNC void qprintff(NUMBER *q, long width, long precision);
 E_FUNC void qprintfe(NUMBER *q, long width, long precision);
-E_FUNC void qprintfr(NUMBER *q, long width, BOOL force);
+E_FUNC void qprintfr(NUMBER *q, long width, bool force);
 E_FUNC void qprintfd(NUMBER *q, long width);
 E_FUNC void qprintfx(NUMBER *q, long width);
 E_FUNC void qprintfb(NUMBER *q, long width);
@@ -119,12 +119,12 @@ E_FUNC NUMBER *qround(NUMBER *q, long places, long rnd);
 E_FUNC NUMBER *qbtrunc(NUMBER *q1, NUMBER *q2);
 E_FUNC NUMBER *qbround(NUMBER *q, long places, long rnd);
 E_FUNC NUMBER *qscale(NUMBER *q, long i);
-E_FUNC BOOL qdivides(NUMBER *q1, NUMBER *q2);
-E_FUNC BOOL qcmp(NUMBER *q1, NUMBER *q2);
-E_FUNC BOOL qcmpi(NUMBER *q, long i);
+E_FUNC bool qdivides(NUMBER *q1, NUMBER *q2);
+E_FUNC bool qcmp(NUMBER *q1, NUMBER *q2);
+E_FUNC bool qcmpi(NUMBER *q, long i);
 E_FUNC FLAG qrel(NUMBER *q1, NUMBER *q2);
 E_FUNC FLAG qreli(NUMBER *q, long i);
-E_FUNC BOOL qisset(NUMBER *q, long i);
+E_FUNC bool qisset(NUMBER *q, long i);
 
 
 /*
@@ -153,13 +153,13 @@ E_FUNC NUMBER *qredcout(NUMBER *q1, NUMBER *q2);
 E_FUNC NUMBER *qredcmul(NUMBER *q1, NUMBER *q2, NUMBER *q3);
 E_FUNC NUMBER *qredcsquare(NUMBER *q1, NUMBER *q2);
 E_FUNC NUMBER *qredcpower(NUMBER *q1, NUMBER *q2, NUMBER *q3);
-E_FUNC BOOL qprimetest(NUMBER *q1, NUMBER *q2, NUMBER *q3);
-E_FUNC BOOL qissquare(NUMBER *q);
+E_FUNC bool qprimetest(NUMBER *q1, NUMBER *q2, NUMBER *q3);
+E_FUNC bool qissquare(NUMBER *q);
 E_FUNC long qilog2(NUMBER *q);
 E_FUNC long qilog10(NUMBER *q);
 E_FUNC NUMBER *qilog(NUMBER *q, ZVALUE base);
-E_FUNC BOOL qcmpmod(NUMBER *q1, NUMBER *q2, NUMBER *q3);
-E_FUNC BOOL qquomod(NUMBER *q1, NUMBER *q2, NUMBER **quo, NUMBER **mod,
+E_FUNC bool qcmpmod(NUMBER *q1, NUMBER *q2, NUMBER *q3);
+E_FUNC bool qquomod(NUMBER *q1, NUMBER *q2, NUMBER **quo, NUMBER **mod,
 		    long rnd);
 E_FUNC FLAG qnear(NUMBER *q1, NUMBER *q2, NUMBER *epsilon);
 E_FUNC NUMBER *qdigit(NUMBER *q, ZVALUE dpos, ZVALUE base);
@@ -167,9 +167,11 @@ E_FUNC long qprecision(NUMBER *q);
 E_FUNC long qplaces(NUMBER *q, ZVALUE base);
 E_FUNC long qdecplaces(NUMBER *q);
 E_FUNC long qdigits(NUMBER *q, ZVALUE base);
+E_FUNC bool check_epsilon(NUMBER *q);
 E_FUNC void setepsilon(NUMBER *q);
 E_FUNC NUMBER *qbitvalue(long i);
 E_FUNC NUMBER *qtenpow(long i);
+E_FUNC bool qispowerof2(NUMBER *q, NUMBER **qlog2);
 
 
 /*
@@ -185,6 +187,8 @@ E_FUNC NUMBER *qsin(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qexp(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qln(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qlog(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qlog2(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qlogn(NUMBER *q, NUMBER *n, NUMBER *epsilon);
 E_FUNC NUMBER *qtan(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qsec(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qcot(NUMBER *q, NUMBER *epsilon);
@@ -209,7 +213,7 @@ E_FUNC NUMBER *qatanh(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qasech(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qacsch(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qacoth(NUMBER *q, NUMBER *epsilon);
-E_FUNC NUMBER *qlegtoleg(NUMBER *q, NUMBER *epsilon, BOOL wantneg);
+E_FUNC NUMBER *qlegtoleg(NUMBER *q, NUMBER *epsilon, bool wantneg);
 E_FUNC NUMBER *qpi(NUMBER *epsilon);
 E_FUNC NUMBER *qpidiv180(NUMBER *epsilon);
 E_FUNC NUMBER *qpidiv200(NUMBER *epsilon);
@@ -219,19 +223,55 @@ E_FUNC void qfreebern(void);
 E_FUNC NUMBER *qeuler(ZVALUE z);
 E_FUNC void qfreeeuler(void);
 
+/*
+ * historical trig functions
+ */
+E_FUNC NUMBER *qversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qaversin_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qaversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qcoversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qacoversin_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qacoversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qvercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qavercos_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qavercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qcovercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qacovercos_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qacovercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qhaversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahaversin_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahaversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qhacoversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahacoversin_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahacoversin(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qhavercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahavercos_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahavercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qhacovercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahacovercos_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qahacovercos(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qexsec(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qaexsec_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qaexsec(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qexcsc(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qaexcsc_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qaexcsc(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qcrd(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qacrd_or_NULL(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qacrd(NUMBER *q, NUMBER *epsilon);
+E_FUNC NUMBER *qcas(NUMBER *q, NUMBER *epsilon);
 
 /*
  * pseudo-seed generator
  */
 E_FUNC NUMBER *pseudo_seed(void);
 
-
 /*
  * external swap functions
  */
-E_FUNC NUMBER *swap_b8_in_NUMBER(NUMBER *dest, NUMBER *src, BOOL all);
-E_FUNC NUMBER *swap_b16_in_NUMBER(NUMBER *dest, NUMBER *src, BOOL all);
-E_FUNC NUMBER *swap_HALF_in_NUMBER(NUMBER *dest, NUMBER *src, BOOL all);
+E_FUNC NUMBER *swap_b8_in_NUMBER(NUMBER *dest, NUMBER *src, bool all);
+E_FUNC NUMBER *swap_b16_in_NUMBER(NUMBER *dest, NUMBER *src, bool all);
+E_FUNC NUMBER *swap_HALF_in_NUMBER(NUMBER *dest, NUMBER *src, bool all);
 
 
 /*
@@ -248,12 +288,12 @@ E_FUNC NUMBER *swap_HALF_in_NUMBER(NUMBER *dest, NUMBER *src, BOOL all);
 #define qistwo(q)	(zistwo((q)->num) && zisunit((q)->den))
 #define qiseven(q)	(zisunit((q)->den) && ziseven((q)->num))
 #define qisodd(q)	(zisunit((q)->den) && zisodd((q)->num))
-#define qistwopower(q)	(zisunit((q)->den) && zistwopower((q)->num))
 #define qistiny(q)	(zistiny((q)->num))
 
 #define qhighbit(q)	(zhighbit((q)->num))
 #define qlowbit(q)	(zlowbit((q)->num))
 #define qdivcount(q1, q2)	(zdivcount((q1)->num, (q2)->num))
+#define qisreciprocal(q)	(zisunit((q)->num) && !ziszero((q)->den))
 /* operation on #q may be undefined, so replace with an inline-function */
 /* was: #define qlink(q)	((q)->links++, (q)) */
 static inline NUMBER* qlink(NUMBER* q) { if(q) { (q)->links++; } return q; }
