@@ -1,7 +1,7 @@
 /*
  * symbol - global and local symbol routines
  *
- * Copyright (C) 1999-2007,2021,2022  David I. Bell and Ernest Bowen
+ * Copyright (C) 1999-2007,2021-2023  David I. Bell and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -35,7 +35,7 @@
 #include "func.h"
 
 
-#include "attribute.h"
+#include "errtbl.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -89,10 +89,10 @@ initglobals(void)
  *
  * given:
  *	name		name of global variable
- *	isstatic	TRUE if symbol is static
+ *	isstatic	true if symbol is static
  */
 GLOBAL *
-addglobal(char *name, BOOL isstatic)
+addglobal(char *name, bool isstatic)
 {
 	GLOBAL *sp;		/* current symbol pointer */
 	GLOBAL **hp;		/* hash table head address */
@@ -241,10 +241,20 @@ printtype(VALUE *vp)
 {
 	int	type;
 	char	*s;
+	char *errsym;
+	bool alloced;
 
 	type = vp->v_type;
 	if (type < 0) {
-		printf("Error %d", -type);
+		errsym = errnum_2_errsym(-type, &alloced);
+		if (errsym == NULL) {
+			printf("Error %d", -type);
+		} else {
+			printf("Error %s", errsym);
+			if (alloced == true) {
+				free(errsym);
+			}
+		}
 		return;
 	}
 	switch (type) {
@@ -493,7 +503,7 @@ exitfuncscope(void)
  * variable is at the same file and function level.
  */
 void
-endscope(char *name, BOOL isglobal)
+endscope(char *name, bool isglobal)
 {
 	GLOBAL *sp;
 	GLOBAL *prevsp;
