@@ -1,7 +1,7 @@
 /*
  * value - generic value manipulation routines
  *
- * Copyright (C) 1999-2007,2014,2017,2021,2022  David I. Bell
+ * Copyright (C) 1999-2007,2014,2017,2021-2023  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -39,7 +39,7 @@
 #include "config.h"
 
 
-#include "attribute.h"
+#include "errtbl.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -687,7 +687,7 @@ invertvalue(VALUE *vp, VALUE *vres)
 	switch (vp->v_type) {
 	case V_NUM:
 		if (qiszero(vp->v_num))
-			*vres = error_value(E_1OVER0);
+			*vres = error_value(E_DIVBYZERO);
 		else
 			vres->v_num = qinv(vp->v_num);
 		return;
@@ -699,7 +699,7 @@ invertvalue(VALUE *vp, VALUE *vres)
 		return;
 	case V_OCTET:
 		if (*vp->v_octet == 0) {
-			*vres = error_value(E_1OVER0);
+			*vres = error_value(E_DIVBYZERO);
 			return;
 		}
 		q1 = itoq((long) *vp->v_octet);
@@ -712,7 +712,7 @@ invertvalue(VALUE *vp, VALUE *vres)
 		*vres = objcall(OBJ_INV, vp, NULL_VALUE, NULL_VALUE);
 		return;
 	default:
-		if (vp->v_type == -E_1OVER0) {
+		if (vp->v_type == -E_DIVBYZERO) {
 			vres->v_type = V_NUM;
 			vres->v_num = qlink(&_qzero_);
 			return;
@@ -1065,12 +1065,12 @@ apprvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	case V_NULL:	e = conf->epsilon;
 			break;
 	default:
-		*vres = error_value(E_APPR2);
+		*vres = error_value(E_APPR_2);
 		return;
 	}
 	switch(v3->v_type) {
 	case V_NUM:	if (qisfrac(v3->v_num)) {
-				*vres = error_value(E_APPR3);
+				*vres = error_value(E_APPR_3);
 				return;
 			}
 			R = qtoi(v3->v_num);
@@ -1078,7 +1078,7 @@ apprvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	case V_NULL:	R = conf->appr;
 			break;
 	default:
-		*vres = error_value(E_APPR3);
+		*vres = error_value(E_APPR_3);
 		return;
 	}
 
@@ -1113,7 +1113,7 @@ apprvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		vres->v_com = c;
 		return;
 	default:
-		*vres = error_value(E_APPR);
+		*vres = error_value(E_APPR_1);
 		return;
 	}
 }
@@ -1148,7 +1148,7 @@ roundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	switch (v2->v_type) {
 	case V_NUM:
 		if (qisfrac(v2->v_num)) {
-			*vres = error_value(E_ROUND2);
+			*vres = error_value(E_ROUND_2);
 			return;
 		}
 		places = qtoi(v2->v_num);
@@ -1156,14 +1156,14 @@ roundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	case V_NULL:
 		break;
 	default:
-		*vres = error_value(E_ROUND2);
+		*vres = error_value(E_ROUND_2);
 		return;
 	}
 	rnd = 0;
 	switch (v3->v_type) {
 	case V_NUM:
 		if (qisfrac(v3->v_num)) {
-			*vres = error_value(E_ROUND3);
+			*vres = error_value(E_ROUND_3);
 			return;
 		}
 		rnd = qtoi(v3->v_num);
@@ -1172,7 +1172,7 @@ roundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		rnd = conf->round;
 		break;
 	default:
-		*vres = error_value(E_ROUND3);
+		*vres = error_value(E_ROUND_3);
 		return;
 	}
 	switch(v1->v_type) {
@@ -1198,7 +1198,7 @@ roundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	default:
 		if (v1->v_type <= 0)
 			return;
-		*vres = error_value(E_ROUND);
+		*vres = error_value(E_ROUND_1);
 		return;
 	}
 }
@@ -1234,7 +1234,7 @@ broundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	switch (v2->v_type) {
 	case V_NUM:
 		if (qisfrac(v2->v_num)) {
-			*vres = error_value(E_BROUND2);
+			*vres = error_value(E_BROUND_2);
 			return;
 		}
 		places = qtoi(v2->v_num);
@@ -1242,14 +1242,14 @@ broundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	case V_NULL:
 		break;
 	default:
-		*vres = error_value(E_BROUND2);
+		*vres = error_value(E_BROUND_2);
 		return;
 	}
 	rnd = 0;
 	switch (v3->v_type) {
 	case V_NUM:
 		if (qisfrac(v3->v_num)) {
-			*vres = error_value(E_BROUND3);
+			*vres = error_value(E_BROUND_3);
 			return;
 		}
 		rnd = qtoi(v3->v_num);
@@ -1258,7 +1258,7 @@ broundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		rnd = conf->round;
 		break;
 	default:
-		*vres = error_value(E_BROUND3);
+		*vres = error_value(E_BROUND_3);
 		return;
 	}
 	switch(v1->v_type) {
@@ -1284,7 +1284,7 @@ broundvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 	default:
 		if (v1->v_type <= 0)
 			return;
-		*vres = error_value(E_BROUND);
+		*vres = error_value(E_BROUND_1);
 		return;
 	}
 }
@@ -1517,7 +1517,7 @@ sqrtvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		q = conf->epsilon;
 	} else {
 		if (v2->v_type != V_NUM || qiszero(v2->v_num)) {
-			*vres = error_value(E_SQRT2);
+			*vres = error_value(E_SQRT_2);
 			return;
 		}
 		q = v2->v_num;
@@ -1526,7 +1526,7 @@ sqrtvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		R = conf->sqrt;
 	} else {
 		if (v3->v_type != V_NUM || qisfrac(v3->v_num)) {
-			*vres = error_value(E_SQRT3);
+			*vres = error_value(E_SQRT_3);
 			return;
 		}
 		R = qtoi(v3->v_num);
@@ -1549,7 +1549,7 @@ sqrtvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		vres->v_com = c_sqrt(v1->v_com, q, R);
 		break;
 	default:
-		*vres = error_value(E_SQRT);
+		*vres = error_value(E_SQRT_1);
 		return;
 	}
 	c = vres->v_com;
@@ -1584,16 +1584,16 @@ rootvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		return;
 	}
 	if (v2->v_type != V_NUM) {
-		*vres = error_value(E_ROOT2);
+		*vres = error_value(E_ROOT_2);
 		return;
 	}
 	q2 = v2->v_num;
 	if (qisneg(q2) || qiszero(q2) || qisfrac(q2)) {
-		*vres = error_value(E_ROOT2);
+		*vres = error_value(E_ROOT_2);
 		return;
 	}
 	if (v3->v_type != V_NUM || qiszero(v3->v_num)) {
-		*vres = error_value(E_ROOT3);
+		*vres = error_value(E_ROOT_3);
 		return;
 	}
 	q3 = v3->v_num;
@@ -1602,7 +1602,7 @@ rootvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		if (!qisneg(v1->v_num)) {
 			vres->v_num = qroot(v1->v_num, q2, q3);
 			if (vres->v_num == NULL)
-				*vres = error_value(E_ROOT4);
+				*vres = error_value(E_ROOT_4);
 			vres->v_type = V_NUM;
 			return;
 		}
@@ -1618,11 +1618,11 @@ rootvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		*vres = objcall(OBJ_ROOT, v1, v2, v3);
 		return;
 	default:
-		*vres = error_value(E_ROOT);
+		*vres = error_value(E_ROOT_1);
 		return;
 	}
 	if (c == NULL) {
-		*vres = error_value(E_ROOT4);
+		*vres = error_value(E_ROOT_4);
 		return;
 	}
 	vres->v_com = c;
@@ -1662,13 +1662,13 @@ absvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 		break;
 	case V_COM:
 		if (v2->v_type != V_NUM || qiszero(v2->v_num)) {
-			*vres = error_value(E_ABS2);
+			*vres = error_value(E_ABS_2);
 			return;
 		}
 		q = qhypot(v1->v_com->real, v1->v_com->imag, v2->v_num);
 		break;
 	default:
-		*vres = error_value(E_ABS);
+		*vres = error_value(E_ABS_1);
 		return;
 	}
 	vres->v_num = q;
@@ -1723,11 +1723,11 @@ normvalue(VALUE *vp, VALUE *vres)
  * given:
  *	v1		value to shift
  *	v2		shift amount
- *	rightshift	TRUE if shift right instead of left
+ *	rightshift	true if shift right instead of left
  *	vres		result
  */
 void
-shiftvalue(VALUE *v1, VALUE *v2, BOOL rightshift, VALUE *vres)
+shiftvalue(VALUE *v1, VALUE *v2, bool rightshift, VALUE *vres)
 {
 	COMPLEX *c;
 	long n = 0;
@@ -1740,12 +1740,12 @@ shiftvalue(VALUE *v1, VALUE *v2, BOOL rightshift, VALUE *vres)
 		return;
 	}
 	if ((v2->v_type != V_NUM) || (qisfrac(v2->v_num))) {
-		*vres = error_value(E_SHIFT2);
+		*vres = error_value(E_SHIFT_2);
 		return;
 	}
 	if (v1->v_type != V_OBJ) {
 		if (zge31b(v2->v_num->num)) {
-			*vres = error_value(E_SHIFT2);
+			*vres = error_value(E_SHIFT_2);
 			return;
 		}
 		n = qtoi(v2->v_num);
@@ -1756,7 +1756,7 @@ shiftvalue(VALUE *v1, VALUE *v2, BOOL rightshift, VALUE *vres)
 	switch (v1->v_type) {
 	case V_NUM:
 		if (qisfrac(v1->v_num)) {
-			*vres = error_value(E_SHIFT);
+			*vres = error_value(E_SHIFT_1);
 			return;
 		}
 		vres->v_num = qshift(v1->v_num, n);
@@ -1764,7 +1764,7 @@ shiftvalue(VALUE *v1, VALUE *v2, BOOL rightshift, VALUE *vres)
 	case V_COM:
 		if (qisfrac(v1->v_com->real) ||
 				qisfrac(v1->v_com->imag)) {
-			*vres = error_value(E_SHIFT);
+			*vres = error_value(E_SHIFT_1);
 			return;
 		}
 		c = c_shift(v1->v_com, n);
@@ -1805,7 +1805,7 @@ shiftvalue(VALUE *v1, VALUE *v2, BOOL rightshift, VALUE *vres)
 		qfree(tmp.v_num);
 		return;
 	default:
-		*vres = error_value(E_SHIFT);
+		*vres = error_value(E_SHIFT_1);
 		return;
 	}
 }
@@ -1826,12 +1826,12 @@ scalevalue(VALUE *v1, VALUE *v2, VALUE *vres)
 		return;
 	}
 	if ((v2->v_type != V_NUM) || qisfrac(v2->v_num)) {
-		*vres = error_value(E_SCALE2);
+		*vres = error_value(E_SCALE_2);
 		return;
 	}
 	if (v1->v_type != V_OBJ) {
 		if (zge31b(v2->v_num->num)) {
-			*vres = error_value(E_SCALE2);
+			*vres = error_value(E_SCALE_2);
 			return;
 		}
 		n = qtoi(v2->v_num);
@@ -1851,7 +1851,7 @@ scalevalue(VALUE *v1, VALUE *v2, VALUE *vres)
 		*vres = objcall(OBJ_SCALE, v1, v2, NULL_VALUE);
 		return;
 	default:
-		*vres = error_value(E_SCALE);
+		*vres = error_value(E_SCALE_1);
 		return;
 	}
 }
@@ -1873,7 +1873,7 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 	}
 	vres->v_type = v1->v_type;
 	vres->v_subtype = V_NOSUBTYPE;
-	if (v1->v_type <= 0 && v1->v_type != -E_1OVER0)
+	if (v1->v_type <= 0 && v1->v_type != -E_DIVBYZERO)
 		return;
 	if (v2->v_type <= 0) {
 		vres->v_type = v2->v_type;
@@ -1886,12 +1886,12 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 	case V_NUM:
 
 		/* deal with the division by 0 value */
-		if (v1->v_type == -E_1OVER0) {
+		if (v1->v_type == -E_DIVBYZERO) {
 			if (qisneg(real_v2)) {
 				vres->v_type = V_NUM;
 				vres->v_num = qlink(&_qzero_);
 			} else {
-				vres->v_type = -E_1OVER0;
+				vres->v_type = -E_DIVBYZERO;
 			}
 			break;
 		}
@@ -1901,7 +1901,7 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 		case V_NUM:
 			if (qiszero(v1->v_num)) {
 				if (qisneg(real_v2)) {
-					*vres = error_value(E_1OVER0);
+					*vres = error_value(E_DIVBYZERO);
 					break;
 				}
 				vres->v_type = V_NUM;
@@ -1941,7 +1941,7 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 			vres->v_mat = matpowi(v1->v_mat, real_v2);
 			break;
 		default:
-			*vres = error_value(E_POWI);
+			*vres = error_value(E_POWI_1);
 			break;
 		}
 		break;
@@ -1949,12 +1949,12 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 	case V_COM:
 
 		/* deal with the division by 0 value */
-		if (v1->v_type == -E_1OVER0) {
+		if (v1->v_type == -E_DIVBYZERO) {
 			if (cisreal(v2->v_com) && qisneg(real_v2)) {
 				vres->v_type = V_NUM;
 				vres->v_num = qlink(&_qzero_);
 			} else {
-				vres->v_type = -E_1OVER0;
+				vres->v_type = -E_DIVBYZERO;
 			}
 			break;
 		}
@@ -1964,7 +1964,7 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 		case V_NUM:
 			if (qiszero(v1->v_num)) {
 				if (cisreal(v2->v_com) && qisneg(real_v2)) {
-					*vres = error_value(E_1OVER0);
+					*vres = error_value(E_DIVBYZERO);
 					break;
 				}
 				/*
@@ -2008,14 +2008,14 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 			}
 			break;
 		default:
-			*vres = error_value(E_POWI);
+			*vres = error_value(E_POWI_1);
 			break;
 		}
 		break;
 
 	/* unsupported exponent type */
 	default:
-		*vres = error_value(E_POWI2);
+		*vres = error_value(E_POWI_2);
 		break;
 	}
 	return;
@@ -2040,11 +2040,11 @@ powervalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		return;
 	}
 	if (v1->v_type != V_NUM && v1->v_type != V_COM) {
-		*vres = error_value(E_POWER);
+		*vres = error_value(E_POWER_1);
 		return;
 	}
 	if (v2->v_type != V_NUM && v2->v_type != V_COM) {
-		*vres = error_value(E_POWER2);
+		*vres = error_value(E_POWER_2);
 		return;
 	}
 
@@ -2053,13 +2053,13 @@ powervalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		epsilon = conf->epsilon;
 	} else {
 		if (v3->v_type != V_NUM || qiszero(v3->v_num)) {
-			*vres = error_value(E_POWER3);
+			*vres = error_value(E_POWER_3);
 			return;
 		}
 		epsilon = v3->v_num;
 	}
 	if (qiszero(epsilon)) {
-		*vres = error_value(E_POWER3);
+		*vres = error_value(E_POWER_3);
 		return;
 	}
 
@@ -2079,7 +2079,7 @@ powervalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		vres->v_num = qpower(v1->v_num, v2->v_num, epsilon);
 		vres->v_type = V_NUM;
 		if (vres->v_num == NULL)
-			*vres = error_value(E_POWER4);
+			*vres = error_value(E_POWER_4);
 		return;
 	case TWOVAL(V_NUM, V_COM):
 		ctmp1.real = v1->v_num;
@@ -2097,7 +2097,7 @@ powervalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		c = c_power(v1->v_com, v2->v_com, epsilon);
 		break;
 	default:
-		*vres = error_value(E_POWER);
+		*vres = error_value(E_POWER_1);
 		return;
 	}
 	/*
@@ -2131,7 +2131,7 @@ divvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 	if (v1->v_type <= 0)
 		return;
 	if (v2->v_type <= 0) {
-		if (testvalue(v1) && v2->v_type == -E_1OVER0) {
+		if (testvalue(v1) && v2->v_type == -E_DIVBYZERO) {
 			vres->v_type = V_NUM;
 			vres->v_num = qlink(&_qzero_);
 		}
@@ -2141,9 +2141,9 @@ divvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 	}
 	if (!testvalue(v2)) {
 		if (testvalue(v1))
-			*vres = error_value(E_1OVER0);
+			*vres = error_value(E_DIVBYZERO);
 		else
-			*vres = error_value(E_0OVER0);
+			*vres = error_value(E_ZERODIVZERO);
 		return;
 	}
 	vres->v_type = v1->v_type;
@@ -2232,14 +2232,14 @@ quovalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		return;
 	}
 	if (v2->v_type != V_NUM) {
-		*vres = error_value(E_QUO2);
+		*vres = error_value(E_QUO_2);
 		return;
 	}
 	rnd = 0;
 	switch (v3->v_type) {
 	case V_NUM:
 		if (qisfrac(v3->v_num)) {
-			*vres = error_value(E_QUO3);
+			*vres = error_value(E_QUO_3);
 			return;
 		}
 		rnd = qtoi(v3->v_num);
@@ -2248,7 +2248,7 @@ quovalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		rnd = conf->quo;
 		break;
 	default:
-		*vres = error_value(E_QUO3);
+		*vres = error_value(E_QUO_3);
 		return;
 	}
 	switch (v1->v_type) {
@@ -2272,7 +2272,7 @@ quovalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		vres->v_com = c;
 		return;
 	default:
-		*vres = error_value(E_QUO);
+		*vres = error_value(E_QUO_1);
 		return;
 	}
 }
@@ -2311,14 +2311,14 @@ modvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		return;
 	}
 	if (v2->v_type != V_NUM) {
-		*vres = error_value(E_MOD2);
+		*vres = error_value(E_MOD_2);
 		return;
 	}
 	rnd = 0;
 	switch (v3->v_type) {
 	case V_NUM:
 		if (qisfrac(v3->v_num)) {
-			*vres = error_value(E_MOD3);
+			*vres = error_value(E_MOD_3);
 			return;
 		}
 		rnd = qtoi(v3->v_num);
@@ -2327,7 +2327,7 @@ modvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		rnd = conf->mod;
 		break;
 	default:
-		*vres = error_value(E_MOD3);
+		*vres = error_value(E_MOD_3);
 		return;
 	}
 	switch (v1->v_type) {
@@ -2351,7 +2351,7 @@ modvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
 		vres->v_com = c;
 		return;
 	default:
-		*vres = error_value(E_MOD);
+		*vres = error_value(E_MOD_1);
 		return;
 	}
 }
@@ -2361,9 +2361,9 @@ modvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres)
  * Test an arbitrary value to see if it is equal to "zero".
  * The definition of zero varies depending on the value type.  For example,
  * the null string is "zero", and a matrix with zero values is "zero".
- * Returns TRUE if value is not equal to zero.
+ * Returns true if value is not equal to zero.
  */
-BOOL
+bool
 testvalue(VALUE *vp)
 {
 	VALUE val;
@@ -2382,9 +2382,9 @@ testvalue(VALUE *vp)
 	case V_LIST:
 		for (ep = vp->v_list->l_first; ep; ep = ep->e_next) {
 			if (testvalue(&ep->e_value))
-				return TRUE;
+				return true;
 		}
-		return FALSE;
+		return false;
 	case V_ASSOC:
 		return (vp->v_assoc->a_count != 0);
 	case V_FILE:
@@ -2397,36 +2397,36 @@ testvalue(VALUE *vp)
 	case V_BLOCK:
 		for (i=0; i < vp->v_block->datalen; ++i) {
 			if (vp->v_block->data[i]) {
-				return TRUE;
+				return true;
 			}
 		}
-		return FALSE;
+		return false;
 	case V_OCTET:
 		return (*vp->v_octet != 0);
 	case V_NBLOCK:
 		if (vp->v_nblock->blk->data == NULL)
-			return FALSE;
+			return false;
 		for (i=0; i < vp->v_nblock->blk->datalen; ++i) {
 			if (vp->v_nblock->blk->data[i]) {
-				return TRUE;
+				return true;
 			}
 		}
-		return FALSE;
+		return false;
 	default:
-		return TRUE;
+		return true;
 	}
-	return FALSE;
+	return false;
 }
 
 
 /*
  * Compare two values for equality.
- * Returns TRUE if the two values differ.
+ * Returns true if the two values differ.
  */
-BOOL
+bool
 comparevalue(VALUE *v1, VALUE *v2)
 {
-	int r = FALSE;
+	int r = false;
 	VALUE val;
 
 	if ((v1->v_type == V_OBJ) || (v2->v_type == V_OBJ)) {
@@ -2434,7 +2434,7 @@ comparevalue(VALUE *v1, VALUE *v2)
 		return (val.v_int != 0);
 	}
 	if (v1 == v2)
-		return FALSE;
+		return false;
 	if (v1->v_type ==  V_OCTET) {
 		if (v2->v_type == V_OCTET)
 			return (*v1->v_octet != *v2->v_octet);
@@ -2443,15 +2443,15 @@ comparevalue(VALUE *v1, VALUE *v2)
 				|| (v2->v_str->s_len != 1);
 		if (v2->v_type != V_NUM || qisfrac(v2->v_num) ||
 			qisneg(v2->v_num) || v2->v_num->num.len > 1)
-				return TRUE;
+				return true;
 		return (*v2->v_num->num.v != *v1->v_octet);
 	}
 	if (v2->v_type == V_OCTET)
 		return comparevalue(v2, v1);
 	if (v1->v_type != v2->v_type)
-		return TRUE;
+		return true;
 	if (v1->v_type <= 0)
-		return FALSE;
+		return false;
 	switch (v1->v_type) {
 	case V_NUM:
 		r = qcmp(v1->v_num, v2->v_num);
@@ -2509,12 +2509,12 @@ comparevalue(VALUE *v1, VALUE *v2)
 	return (r != 0);
 }
 
-BOOL
+bool
 acceptvalue(VALUE *v1, VALUE *v2)
 {
 	long index;
 	FUNC *fp;
-	BOOL ret;
+	bool ret;
 
 	index = adduserfunc("accept");
 	fp = findfunc(index);
@@ -2536,14 +2536,14 @@ acceptvalue(VALUE *v1, VALUE *v2)
 }
 
 
-BOOL
+bool
 precvalue(VALUE *v1, VALUE *v2)
 {
 	VALUE val;
 	long index;
 	int r = 0;
 	FUNC *fp;
-	BOOL ret;
+	bool ret;
 
 	index = adduserfunc("precedes");
 	fp = findfunc(index);
@@ -2794,15 +2794,31 @@ printvalue(VALUE *vp, int flags)
 {
 	NUMBER *qtemp;
 	int type;
+	char *errsym;
+	bool alloced;
 
 	type = vp->v_type;
 	if (type < 0) {
-		if (userfunc("error_print", vp))
+		if (userfunc("error_print", vp)) {
 			return;
-		if (-type >= E__BASE)
-			math_fmt("Error %d", -type);
-		else
-			math_fmt("System error %d", -type);
+		}
+		errsym = errnum_2_errsym(-type, &alloced);
+		if (errsym == NULL) {
+			if (-type >= E__BASE) {
+				math_fmt("Error %d", -type);
+			} else {
+				math_fmt("System error %d", -type);
+			}
+		} else {
+			if (-type >= E__BASE) {
+				math_fmt("Error %s", errsym);
+			} else {
+				math_fmt("System error %s", errsym);
+			}
+			if (alloced == true) {
+				free(errsym);
+			}
+		}
 		return;
 	}
 	switch (type) {
@@ -3017,7 +3033,7 @@ config_print(CONFIG *cfg)
 {
 	NAMETYPE *cp;
 	VALUE tmp;
-	int tab_over;		/* TRUE => OK move over one tab stop */
+	int tab_over;		/* true => OK move over one tab stop */
 	size_t len;
 
 	/*
@@ -3032,7 +3048,7 @@ config_print(CONFIG *cfg)
 	/*
 	 * print each element
 	 */
-	tab_over = FALSE;
+	tab_over = false;
 	for (cp = configs; cp->name; cp++) {
 
 		/* skip if special all or duplicate maxerr value */
@@ -3044,7 +3060,7 @@ config_print(CONFIG *cfg)
 		if (tab_over) {
 			math_str("\t");
 		} else if (conf->tab_ok) {
-			tab_over = TRUE;	/* tab next time */
+			tab_over = true;	/* tab next time */
 		}
 
 		/* print name and spaces */
