@@ -1,7 +1,7 @@
 /*
  * value - definitions of general values  and related routines used by calc
  *
- * Copyright (C) 1999-2007,2014,2021  David I. Bell
+ * Copyright (C) 1999-2007,2014,2021,2023  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -33,21 +33,21 @@
 # include "cmath.h"
 # include "config.h"
 # include "sha1.h"
-# include "calcerr.h"
 # include "hash.h"
 # include "block.h"
 # include "nametype.h"
 # include "str.h"
+# include "errtbl.h"
 #else
 # include <calc/decl.h>
 # include <calc/cmath.h>
 # include <calc/config.h>
 # include <calc/sha1.h>
-# include <calc/calcerr.h>
 # include <calc/hash.h>
 # include <calc/block.h>
 # include <calc/nametype.h>
 # include <calc/str.h>
+# include <calc/errtbl.h>
 #endif
 
 
@@ -81,9 +81,12 @@ typedef struct random RANDOM;
  * calc values
  *
  * See below for information on what needs to be added for a new type.
+ *
+ * NOTE: The v_type can be a negative value.  This happens when
+ *	 an error is returned as a VALUE.
  */
 struct value {
-	short v_type;			/* type of value */
+	short v_type;			/* type of value - IMPORTANT: v_type < 0 is an error code */
 	unsigned short v_subtype;	/* other data related to some types */
 	union {				/* types of values (see V_XYZ below) */
 		long vv_int;		/* 1: small integer value */
@@ -170,23 +173,28 @@ struct value {
 
 #define V_MAX	V_NPTR	/* highest legal value - must be last and match highest V_something value */
 
+/*
+ * v_subtype values
+ */
 #define V_NOSUBTYPE	0	/* subtype has no meaning */
-#define V_NOASSIGNTO	1	/* protection status 1 */
-#define V_NONEWVALUE	2	/* protection status 2 */
-#define V_NONEWTYPE	4	/* protection status 4 */
-#define V_NOERROR	8	/* protection status 8 */
-#define V_NOCOPYTO	16	/* protection status 16 */
-#define V_NOREALLOC	32	/* protection status 32 */
-#define V_NOASSIGNFROM	64	/* protection status 64 */
-#define V_NOCOPYFROM	128	/* protection status 128 */
-#define V_PROTECTALL	256	/* protection status 256 */
+#define V_NOASSIGNTO	0x001	/* protection status 1 */
+#define V_NONEWVALUE	0x002	/* protection status 2 */
+#define V_NONEWTYPE	0x004	/* protection status 4 */
+#define V_NOERROR	0x008	/* protection status 8 */
+#define V_NOCOPYTO	0x010	/* protection status 16 */
+#define V_NOREALLOC	0x020	/* protection status 32 */
+#define V_NOASSIGNFROM	0x040	/* protection status 64 */
+#define V_NOCOPYFROM	0x080	/* protection status 128 */
+#define V_PROTECTALL	0x100	/* protection status 256 */
 
-#define MAXPROTECT	511
+#define MAXPROTECT	0x1ff	/* OR of all of the above protection statuses */
 
 /*
  * At present protect(var, sts) determines bits in var->v_subtype
  * corresponding to 4 * sts.  MAXPROTECT is the sum of the simple
  * (power of two) protection status values.
+ *
+ * XXX - consider isseu #52 with respect to protect - XXX
  */
 
 
@@ -265,22 +273,22 @@ E_FUNC void sqrtvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres);
 E_FUNC void rootvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres);
 E_FUNC void absvalue(VALUE *v1, VALUE *v2, VALUE *vres);
 E_FUNC void normvalue(VALUE *vp, VALUE *vres);
-E_FUNC void shiftvalue(VALUE *v1, VALUE *v2, BOOL rightshift, VALUE *vres);
+E_FUNC void shiftvalue(VALUE *v1, VALUE *v2, bool rightshift, VALUE *vres);
 E_FUNC void scalevalue(VALUE *v1, VALUE *v2, VALUE *vres);
 E_FUNC void powvalue(VALUE *v1, VALUE *v2, VALUE *vres);
 E_FUNC void powervalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres);
 E_FUNC void divvalue(VALUE *v1, VALUE *v2, VALUE *vres);
 E_FUNC void quovalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres);
 E_FUNC void modvalue(VALUE *v1, VALUE *v2, VALUE *v3, VALUE *vres);
-E_FUNC BOOL testvalue(VALUE *vp);
-E_FUNC BOOL comparevalue(VALUE *v1, VALUE *v2);
-E_FUNC BOOL acceptvalue(VALUE *v1, VALUE *v2);
+E_FUNC bool testvalue(VALUE *vp);
+E_FUNC bool comparevalue(VALUE *v1, VALUE *v2);
+E_FUNC bool acceptvalue(VALUE *v1, VALUE *v2);
 E_FUNC void relvalue(VALUE *v1, VALUE *v2, VALUE *vres);
 E_FUNC void sgnvalue(VALUE *vp, VALUE *vres);
 E_FUNC QCKHASH hashvalue(VALUE *vp, QCKHASH val);
 E_FUNC void printvalue(VALUE *vp, int flags);
 E_FUNC void printestr(VALUE *vp);
-E_FUNC BOOL precvalue(VALUE *v1, VALUE *v2);
+E_FUNC bool precvalue(VALUE *v1, VALUE *v2);
 E_FUNC VALUE error_value(int e);
 E_FUNC int set_errno(int e);
 E_FUNC int set_errcount(int e);
@@ -329,9 +337,9 @@ E_FUNC MATRIX *matappr(MATRIX *m, VALUE *v2, VALUE *v3);
 E_FUNC VALUE mattrace(MATRIX *m);
 E_FUNC MATRIX *mattrans(MATRIX *m);
 E_FUNC MATRIX *matcross(MATRIX *m1, MATRIX *m2);
-E_FUNC BOOL mattest(MATRIX *m);
+E_FUNC bool mattest(MATRIX *m);
 E_FUNC void matsum(MATRIX *m, VALUE *vres);
-E_FUNC BOOL matcmp(MATRIX *m1, MATRIX *m2);
+E_FUNC bool matcmp(MATRIX *m1, MATRIX *m2);
 E_FUNC int matsearch(MATRIX *m, VALUE *vp, long start, long end, ZVALUE *index);
 E_FUNC int matrsearch(MATRIX *m, VALUE *vp, long start, long end,
 		      ZVALUE *index);
@@ -340,10 +348,10 @@ E_FUNC VALUE matdot(MATRIX *m1, MATRIX *m2);
 E_FUNC void matfill(MATRIX *m, VALUE *v1, VALUE *v2);
 E_FUNC void matfree(MATRIX *m);
 E_FUNC void matprint(MATRIX *m, long max_print);
-E_FUNC VALUE *matindex(MATRIX *mp, BOOL create, long dim, VALUE *indices);
+E_FUNC VALUE *matindex(MATRIX *mp, bool create, long dim, VALUE *indices);
 E_FUNC void matreverse(MATRIX *m);
 E_FUNC void matsort(MATRIX *m);
-E_FUNC BOOL matisident(MATRIX *m);
+E_FUNC bool matisident(MATRIX *m);
 E_FUNC MATRIX *matround(MATRIX *m, VALUE *v2, VALUE *v3);
 E_FUNC MATRIX *matbround(MATRIX *m, VALUE *v2, VALUE *v3);
 
@@ -383,7 +391,7 @@ E_FUNC void listprint(LIST *lp, long max_print);
 E_FUNC int listsearch(LIST *lp, VALUE *vp, long start, long end, ZVALUE *index);
 E_FUNC int listrsearch(LIST *lp, VALUE *vp, long start, long end,
 		       ZVALUE *index);
-E_FUNC BOOL listcmp(LIST *lp1, LIST *lp2);
+E_FUNC bool listcmp(LIST *lp1, LIST *lp2);
 E_FUNC VALUE *listfindex(LIST *lp, long index);
 E_FUNC LIST *listalloc(void);
 E_FUNC LIST *listcopy(LIST *lp);
@@ -394,8 +402,8 @@ E_FUNC LIST *listround(LIST *m, VALUE *v2, VALUE *v3);
 E_FUNC LIST *listbround(LIST *m, VALUE *v2, VALUE *v3);
 E_FUNC LIST *listquo(LIST *lp, VALUE *v2, VALUE *v3);
 E_FUNC LIST *listmod(LIST *lp, VALUE *v2, VALUE *v3);
-E_FUNC BOOL evp(LISTELEM *cp, LISTELEM *x, VALUE *vres);
-E_FUNC BOOL evalpoly(LIST *clist, LISTELEM *x, VALUE *vres);
+E_FUNC bool evp(LISTELEM *cp, LISTELEM *x, VALUE *vres);
+E_FUNC bool evalpoly(LIST *clist, LISTELEM *x, VALUE *vres);
 E_FUNC void insertitems(LIST *lp1, LIST *lp2);
 E_FUNC LISTELEM *listelement(LIST *, long);
 E_FUNC LIST *listsegment(LIST *, long, long);
@@ -431,9 +439,9 @@ E_FUNC int assocsearch(ASSOC *ap, VALUE *vp, long start, long end,
 		       ZVALUE *index);
 E_FUNC int assocrsearch(ASSOC *ap, VALUE *vp, long start, long end,
 			ZVALUE *index);
-E_FUNC BOOL assoccmp(ASSOC *ap1, ASSOC *ap2);
+E_FUNC bool assoccmp(ASSOC *ap1, ASSOC *ap2);
 E_FUNC VALUE *assocfindex(ASSOC *ap, long index);
-E_FUNC VALUE *associndex(ASSOC *ap, BOOL create, long dim, VALUE *indices);
+E_FUNC VALUE *associndex(ASSOC *ap, bool create, long dim, VALUE *indices);
 
 
 /*
@@ -567,12 +575,12 @@ E_FUNC STRING *stringncpy(STRING *, STRING *, size_t);
 E_FUNC long stringcontent(STRING *s);
 E_FUNC long stringlowbit(STRING *s);
 E_FUNC long stringhighbit(STRING *s);
-E_FUNC BOOL stringcmp(STRING *, STRING *);
-E_FUNC BOOL stringrel(STRING *, STRING *);
-E_FUNC BOOL stringcaserel(STRING *, STRING *);
+E_FUNC bool stringcmp(STRING *, STRING *);
+E_FUNC FLAG stringrel(STRING *, STRING *);
+E_FUNC FLAG stringcaserel(STRING *, STRING *);
 E_FUNC int stringbit(STRING *, long);
-E_FUNC BOOL stringtest(STRING *);
-E_FUNC int stringsetbit(STRING *, long, BOOL);
+E_FUNC bool stringtest(STRING *);
+E_FUNC int stringsetbit(STRING *, long, bool);
 E_FUNC int stringsearch(STRING *, STRING *, long, long, ZVALUE *);
 E_FUNC int stringrsearch(STRING *, STRING *, long, long, ZVALUE *);
 
