@@ -80,7 +80,13 @@ char *Copyright = "\n"
   "\n"
   "Calc is open software; you can redistribute it and/or modify it under\n"
   "the terms of the version 2.1 of the GNU Lesser General Public License\n"
-  "as published by the Free Software Foundation.\n";
+  "as published by the Free Software Foundation.\n"
+  "\n"
+  "Please see the file COPYING, or use the calc command:\n"
+  "\n"
+  "\thelp copying\n"
+  "\n"
+  "for important copyright and license information!\n";
 char *Usability = "\n"
   "Calc is distributed in the hope that it will be useful, but WITHOUT\n"
   "ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n"
