@@ -1,7 +1,7 @@
 /*
  * zfunc - extended precision integral arithmetic non-primitive routines
  *
- * Copyright (C) 1999-2007,2021,2022  David I. Bell, Landon Curt Noll and Ernest Bowen
+ * Copyright (C) 1999-2007,2021-2023  David I. Bell, Landon Curt Noll and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -30,7 +30,7 @@
 #include "alloc.h"
 
 
-#include "attribute.h"
+#include "errtbl.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -194,6 +194,12 @@ zfact(ZVALUE z, ZVALUE *dest)
 	long mul;		/* collected value to multiply by */
 	ZVALUE res, temp;
 
+	/* firewall */
+	if (dest == NULL) {
+		math_error("%s: dest NULL", __func__);
+		not_reached();
+	}
+
 	if (zisneg(z)) {
 		math_error("Negative argument for factorial");
 		not_reached();
@@ -247,6 +253,12 @@ zperm(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	SFULL count;
 	ZVALUE cur, tmp, ans;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (zisneg(z1) || zisneg(z2)) {
 		math_error("Negative argument for permutation");
 		not_reached();
@@ -289,6 +301,12 @@ docomb(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	HALF dh[1];
 #endif
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (zrel(z2, z1) > 0)
 		return 0;
 	zsub(z1, z2, &temp);
@@ -347,6 +365,12 @@ zcomb(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	ZVALUE z3, z4;
 	int r;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (z2.sign || (!z1.sign && zrel(z2, z1) > 0))
 		return 0;
 	if (zisone(z2))
@@ -466,6 +490,12 @@ zfib(ZVALUE z, ZVALUE *res)
 	ZVALUE t1, t2, t3;
 	FULL i;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (zge31b(z)) {
 		math_error("Very large Fibonacci number");
 		not_reached();
@@ -478,7 +508,7 @@ zfib(ZVALUE z, ZVALUE *res)
 	sign = z.sign && ((n & 0x1) == 0);
 	if (n <= 2) {
 		*res = _one_;
-		res->sign = (BOOL)sign;
+		res->sign = (bool)sign;
 		return;
 	}
 	i = TOPFULL;
@@ -512,7 +542,7 @@ zfib(ZVALUE z, ZVALUE *res)
 	zfree(fnm1);
 	zfree(fnp1);
 	*res = fn;
-	res->sign = (BOOL)sign;
+	res->sign = (bool)sign;
 }
 
 
@@ -530,6 +560,12 @@ zpowi(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	long twos;		/* count of times 2 is in result */
 	ZVALUE ans, temp;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	sign = (z1.sign && zisodd(z2));
 	z1.sign = 0;
 	z2.sign = 0;
@@ -539,7 +575,7 @@ zpowi(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	}
 	if (zisabsleone(z1)) {	/* 0, 1, or -1 raised to a power */
 		ans = _one_;
-		ans.sign = (BOOL)sign;
+		ans.sign = (bool)sign;
 		if (*z1.v == 0)
 			ans = _zero_;
 		*res = ans;
@@ -559,7 +595,7 @@ zpowi(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	 */
 	if (zistiny(z1) && (*z1.v == 10)) {
 		ztenpow((long) power, res);
-		res->sign = (BOOL)sign;
+		res->sign = (bool)sign;
 		return;
 	}
 	/*
@@ -571,7 +607,7 @@ zpowi(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 			ans.len = z1.len;
 			ans.v = alloc(ans.len);
 			zcopyval(z1, ans);
-			ans.sign = (BOOL)sign;
+			ans.sign = (bool)sign;
 			*res = ans;
 			return;
 		case 2:
@@ -581,7 +617,7 @@ zpowi(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 			zsquare(z1, &temp);
 			zmul(z1, temp, res);
 			zfree(temp);
-			res->sign = (BOOL)sign;
+			res->sign = (bool)sign;
 			return;
 		case 4:
 			zsquare(z1, &temp);
@@ -641,7 +677,7 @@ zpowi(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 		ans = temp;
 		zfree(z1);
 	}
-	ans.sign = (BOOL)sign;
+	ans.sign = (bool)sign;
 	*res = ans;
 }
 
@@ -657,6 +693,12 @@ ztenpow(long power, ZVALUE *res)
 	ZVALUE ans;
 	ZVALUE temp;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (power <= 0) {
 		*res = _one_;
 		return;
@@ -687,15 +729,21 @@ ztenpow(long power, ZVALUE *res)
  * Calculate modular inverse suppressing unnecessary divisions.
  * This is based on the Euclidean algorithm for large numbers.
  * (Algorithm X from Knuth Vol 2, section 4.5.2. and exercise 17)
- * Returns TRUE if there is no solution because the numbers
+ * Returns true if there is no solution because the numbers
  * are not relatively prime.
  */
-BOOL
+bool
 zmodinv(ZVALUE u, ZVALUE v, ZVALUE *res)
 {
 	FULL	q1, q2, ui3, vi3, uh, vh, A, B, C, D, T;
 	ZVALUE	u2, u3, v2, v3, qz, tmp1, tmp2, tmp3;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	v.sign = 0;
 	if (zisneg(u) || (zrel(u, v) >= 0))
 		zmod(u, v, &v3, 0);
@@ -813,7 +861,7 @@ zmodinv(ZVALUE u, ZVALUE v, ZVALUE *res)
 		zfree(v3);
 		zfree(u2);
 		zfree(v2);
-		return TRUE;
+		return true;
 	}
 	ui3 = ztofull(u3);
 	vi3 = ztofull(v3);
@@ -834,15 +882,15 @@ zmodinv(ZVALUE u, ZVALUE v, ZVALUE *res)
 	zfree(v2);
 	if (ui3 != 1) {
 		zfree(u2);
-		return TRUE;
+		return true;
 	}
 	if (zisneg(u2)) {
 		zadd(v, u2, res);
 		zfree(u2);
-		return FALSE;
+		return false;
 	}
 	*res = u2;
-	return FALSE;
+	return false;
 }
 
 
@@ -858,7 +906,13 @@ zgcd(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	HALF *a, *a0, *A, *b, *b0, *B, *c, *d;
 	FULL f, g;
 	ZVALUE gcd;
-	BOOL needw;
+	bool needw;
+
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
 
 	if (zisunit(z1) || zisunit(z2)) {
 		*res = _one_;
@@ -979,7 +1033,7 @@ zgcd(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	k = (n	- 1) * BASEB;
 	while (u >>= 1) k++;
 
-	needw = TRUE;
+	needw = true;
 
 	w = 0;
 	j = 0;
@@ -1019,7 +1073,7 @@ zgcd(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 			b0 = a;
 			k = j;
 			h = -h;
-			needw = TRUE;
+			needw = true;
 		}
 		if (h > 1) {
 			if (needw) {		/* find w = minv(*b0, h0) */
@@ -1032,7 +1086,7 @@ zgcd(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 					if (u & x) { u -= v * x; w |= x;}
 					x <<= 1;
 				}
-				needw = FALSE;
+				needw = false;
 			}
 			g = (FULL) (*a0 * w);
 			if (h < BASEB) {
@@ -1179,6 +1233,12 @@ zlcm(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 {
 	ZVALUE temp1, temp2;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	zgcd(z1, z2, &temp1);
 	zequo(z1, temp1, &temp2);
 	zfree(temp1);
@@ -1190,23 +1250,23 @@ zlcm(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 /*
  * Return whether or not two numbers are relatively prime to each other.
  */
-BOOL
+bool
 zrelprime(ZVALUE z1, ZVALUE z2)
 {
 	FULL rem1, rem2;		/* remainders */
 	ZVALUE rem;
-	BOOL result;
+	bool result;
 
 	z1.sign = 0;
 	z2.sign = 0;
 	if (ziseven(z1) && ziseven(z2)) /* false if both even */
-		return FALSE;
+		return false;
 	if (zisunit(z1) || zisunit(z2)) /* true if either is a unit */
-		return TRUE;
+		return true;
 	if (ziszero(z1) || ziszero(z2)) /* false if either is zero */
-		return FALSE;
+		return false;
 	if (zistwo(z1) || zistwo(z2))	/* true if either is two */
-		return TRUE;
+		return true;
 	/*
 	 * Try reducing each number by the product of the first few odd primes
 	 * to see if any of them are a common factor.
@@ -1214,26 +1274,26 @@ zrelprime(ZVALUE z1, ZVALUE z2)
 	rem1 = zmodi(z1, (FULL)3 * 5 * 7 * 11 * 13);
 	rem2 = zmodi(z2, (FULL)3 * 5 * 7 * 11 * 13);
 	if (((rem1 % 3) == 0) && ((rem2 % 3) == 0))
-		return FALSE;
+		return false;
 	if (((rem1 % 5) == 0) && ((rem2 % 5) == 0))
-		return FALSE;
+		return false;
 	if (((rem1 % 7) == 0) && ((rem2 % 7) == 0))
-		return FALSE;
+		return false;
 	if (((rem1 % 11) == 0) && ((rem2 % 11) == 0))
-		return FALSE;
+		return false;
 	if (((rem1 % 13) == 0) && ((rem2 % 13) == 0))
-		return FALSE;
+		return false;
 	/*
 	 * Try a new batch of primes now
 	 */
 	rem1 = zmodi(z1, (FULL)17 * 19 * 23);
 	rem2 = zmodi(z2, (FULL)17 * 19 * 23);
 	if (((rem1 % 17) == 0) && ((rem2 % 17) == 0))
-		return FALSE;
+		return false;
 	if (((rem1 % 19) == 0) && ((rem2 % 19) == 0))
-		return FALSE;
+		return false;
 	if (((rem1 % 23) == 0) && ((rem2 % 23) == 0))
-		return FALSE;
+		return false;
 	/*
 	 * Yuk, we must actually compute the gcd to know the answer
 	 */
@@ -1322,11 +1382,11 @@ zlog(ZVALUE z, ZVALUE base)
 /*
  * Return the integral log base 10 of a number.
  *
- * If was_10_power != NULL, then this flag is set to TRUE if the
- * value was a power of 10, FALSE otherwise.
+ * If was_10_power != NULL, then this flag is set to true if the
+ * value was a power of 10, false otherwise.
  */
 long
-zlog10(ZVALUE z, BOOL *was_10_power)
+zlog10(ZVALUE z, bool *was_10_power)
 {
 	ZVALUE *zp;			/* current square */
 	long power;			/* current power */
@@ -1335,6 +1395,8 @@ zlog10(ZVALUE z, BOOL *was_10_power)
 	FLAG rel;			/* relationship */
 	int i;
 
+	/* NOTE: It is OK if was_10_power == NULL */
+
 	if (ziszero(z)) {
 		math_error("Zero argument argument for zlog10");
 		not_reached();
@@ -1368,7 +1430,7 @@ zlog10(ZVALUE z, BOOL *was_10_power)
 
 	/* assume not a power of ten unless we find out otherwise */
 	if (was_10_power != NULL) {
-		*was_10_power = FALSE;
+		*was_10_power = false;
 	}
 
 	/* quick exit for small values */
@@ -1378,7 +1440,7 @@ zlog10(ZVALUE z, BOOL *was_10_power)
 		for (i=0; i <= max_power10_exp; ++i) {
 			if (value == power10[i]) {
 				if (was_10_power != NULL) {
-					*was_10_power = TRUE;
+					*was_10_power = true;
 				}
 				return i;
 			} else if (value < power10[i]) {
@@ -1413,7 +1475,7 @@ zlog10(ZVALUE z, BOOL *was_10_power)
 		if (rel == 0) {
 			/* quick return - we match a tenpower entry */
 			if (was_10_power != NULL) {
-				*was_10_power = TRUE;
+				*was_10_power = true;
 			}
 			return (1L << (zp - _tenpowers_));
 		}
@@ -1437,7 +1499,7 @@ zlog10(ZVALUE z, BOOL *was_10_power)
 			/* exact power of 10 match */
 			power += (1L << (zp - _tenpowers_));
 			if (was_10_power != NULL) {
-				*was_10_power = TRUE;
+				*was_10_power = true;
 			}
 			zfree(pow10);
 			zfree(temp);
@@ -1493,6 +1555,12 @@ zfacrem(ZVALUE z1, ZVALUE z2, ZVALUE *rem)
 	ZVALUE temp1, temp2, temp3;	/* temporaries */
 	ZVALUE squares[32];		/* table of squares of factor */
 
+	/* firewall */
+	if (rem == NULL) {
+		math_error("%s: rem NULL", __func__);
+		not_reached();
+	}
+
 	z1.sign = 0;
 	z2.sign = 0;
 	/*
@@ -1623,6 +1691,12 @@ zgcdrem(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	long count, onecount;
 	long sh;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z1) || ziszero(z2)) {
 		math_error("Zero argument in call to zgcdrem!!!");
 		not_reached();
@@ -1750,9 +1824,15 @@ zsqrt(ZVALUE z, ZVALUE *dest, long rnd)
 	int i, j, j1, j2, k, k1, m, m0, m1, n, n0, o;
 	FULL d, e, f, g, h, s, t, x, topbit;
 	int remsign;
-	BOOL up, onebit;
+	bool up, onebit;
 	ZVALUE sqrt;
 
+	/* firewall */
+	if (dest == NULL) {
+		math_error("%s: dest NULL", __func__);
+		not_reached();
+	}
+
 	if (z.sign) {
 		math_error("Square root of negative number");
 		not_reached();
@@ -1874,7 +1954,7 @@ zsqrt(ZVALUE z, ZVALUE *dest, long rnd)
 		k1 = 1;
 	}
 	h = e >> k;
-	onebit = ((e & ((FULL)1 << (k - 1))) ? TRUE : FALSE);
+	onebit = ((e & ((FULL)1 << (k - 1))) ? true : false);
 	j2 = BASEB - k1;
 	j1 = BASEB + j2;
 	while (m > n0) {
@@ -1980,9 +2060,9 @@ done:	if (s == 0) {
 	}
 	else
 	if (rnd & 8)
-		up = (((rnd ^ *a0) & 1) ? TRUE : FALSE);
+		up = (((rnd ^ *a0) & 1) ? true : false);
 	else
-		up = ((rnd & 1) ? TRUE : FALSE);
+		up = ((rnd & 1) ? true : false);
 	if (up) {
 		remsign = -1;
 		i = n;
@@ -2023,6 +2103,12 @@ zroot(ZVALUE z1, ZVALUE z2, ZVALUE *dest)
 	LEN highbit, k;
 	SIUNION sival;
 
+	/* firewall */
+	if (dest == NULL) {
+		math_error("%s: dest NULL", __func__);
+		not_reached();
+	}
+
 	sign = z1.sign;
 	if (sign && ziseven(z2)) {
 		math_error("Even root of negative number");
@@ -2042,14 +2128,14 @@ zroot(ZVALUE z1, ZVALUE z2, ZVALUE *dest)
 	}
 	if (zge31b(z2)) {	/* humongous root */
 		*dest = _one_;
-		dest->sign = (BOOL)((HALF)sign);
+		dest->sign = (bool)((HALF)sign);
 		return;
 	}
 	k = (LEN)ztolong(z2);
 	highbit = zhighbit(z1);
 	if (highbit < k) {	/* too high a root */
 		*dest = _one_;
-		dest->sign = (BOOL)((HALF)sign);
+		dest->sign = (bool)((HALF)sign);
 		return;
 	}
 	sival.ivalue = k - 1;
@@ -2095,7 +2181,7 @@ zroot(ZVALUE z1, ZVALUE z2, ZVALUE *dest)
 			if ((i == 0) || (zcmp(old, ztry) == 0)) {
 				zfree(quo);
 				zfree(old);
-				ztry.sign = (BOOL)((HALF)sign);
+				ztry.sign = (bool)((HALF)sign);
 				zquicktrim(ztry);
 				*dest = ztry;
 				return;
@@ -2118,7 +2204,7 @@ zroot(ZVALUE z1, ZVALUE z2, ZVALUE *dest)
 /*
  * Test to see if a number is an exact square or not.
  */
-BOOL
+bool
 zissquare(ZVALUE z)
 {
 	long n;
@@ -2126,7 +2212,7 @@ zissquare(ZVALUE z)
 
 	/* negative values are never perfect squares */
 	if (zisneg(z)) {
-		return FALSE;
+		return false;
 	}
 
 	/* ignore trailing zero words */
@@ -2137,16 +2223,91 @@ zissquare(ZVALUE z)
 
 	/* zero or one is a perfect square */
 	if (zisabsleone(z)) {
-		return TRUE;
+		return true;
 	}
 
 	/* check mod 4096 values */
 	if (issq_mod4k[(int)(*z.v & 0xfff)] == 0) {
-		return FALSE;
+		return false;
 	}
 
 	/* must do full square root test now */
 	n = !zsqrt(z, &tmp, 0);
 	zfree(tmp);
-	return (n ? TRUE : FALSE);
+	return (n ? true : false);
+}
+
+
+/*
+ * test if a number is an integer power of 2
+ *
+ * given:
+ *	z	value to check if it is a power of 2
+ *	log2	when z is an integer power of 2 (true return), *log2 is set to log base 2 of z
+ *		when z is NOT an integer power of 2 (false return), *log2 is not touched
+ *
+ * returns:
+ *	true	z is a power of 2
+ *	false	z is not a power of 2
+ */
+bool
+zispowerof2(ZVALUE z, FULL *log2)
+{
+	FULL ilogz;		/* potential log base 2 return value or -1 */
+	HALF tophalf;		/* most significant HALF in z */
+	LEN len;		/* length of z in HALFs */
+	int i;
+
+	/* firewall */
+	if (log2 == NULL) {
+		math_error("%s: log2 NULL", __func__);
+		not_reached();
+	}
+
+	/* zero and negative values are never integer powers of 2 */
+	if (ziszero(z) || zisneg(z)) {
+		return false;
+	}
+
+	/*
+	 * trim z just in case
+	 *
+	 * An untrimmed z will give incorrect results.
+	 */
+	ztrim(&z);
+
+	/*
+	 * all HALFs below the top HALF must be zero
+	 */
+	len = z.len;
+	for (i=0, ilogz=0; i < len-1; ++i, ilogz+=BASEB) {
+		if (z.v[i] != 0) {
+			return false;
+		}
+	}
+
+	/*
+	 * top HALF must be a power of 2
+	 *
+	 * For non-zero values of tophalf,
+	 * (tophalf & (tophalf-1)) == 0 ==> tophalf is a power of 2,
+	 * (tophalf & (tophalf-1)) != 0 ==> tophalf is NOT a power of 2.
+	 */
+	tophalf = z.v[len-1];
+	if ((tophalf == 0) || ((tophalf & (tophalf-1)) != 0)) {
+		return false;
+	}
+
+	/*
+	 * count the bits in the top HALF which is a power of 2
+	 */
+	for (i=0; i < BASEB && tophalf != ((HALF)1 << i); ++i) {
+		++ilogz;
+	}
+
+	/*
+	 * return power of 2
+	 */
+	*log2 = ilogz;
+	return true;
 }
