@@ -1,7 +1,7 @@
 /*
  * zmath - extended precision integral arithmetic primitives
  *
- * Copyright (C) 1999-2007,2021,2022  David I. Bell and Ernest Bowen
+ * Copyright (C) 1999-2007,2021-2023  David I. Bell, Landon Curt Noll and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -27,11 +27,12 @@
 
 
 #include <stdio.h>
+#include "int.h"
 #include "alloc.h"
 #include "zmath.h"
 
 
-#include "attribute.h"
+#include "errtbl.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -196,7 +197,7 @@ HALF bitmask[(2*BASEB)+1] = {
 #endif
 };		/* actual rotation thru 8 cycles */
 
-BOOL _math_abort_;		/* nonzero to abort calculations */
+bool _math_abort_;		/* nonzero to abort calculations */
 
 
 /*
@@ -254,26 +255,32 @@ alloc(LEN len)
  * is_const - determine if a HALF array is an pre-allocated array
  *
  * given:
- * 	h	pointer to the beginning of the HALF array
+ *	h	pointer to the beginning of the HALF array
  *
  * returns:
- * 	TRUE - h is found in the half_tbl array
- * 	FALSE - is is not found in the half_tbl array
+ *	true - h is found in the half_tbl array
+ *	false - is is not found in the half_tbl array
  */
 int
-is_const(HALF* h)
+is_const(HALF *h)
 {
 	HALF **h_p;	/* half_tbl array pointer */
 
+	/* firewall */
+	if (h == NULL) {
+		math_error("%s: h NULL", __func__);
+		not_reached();
+	}
+
 	/* search the half_tbl for h */
 	for (h_p = &half_tbl[0]; *h_p != NULL; ++h_p) {
 		if (h == *h_p) {
-			return TRUE;	/* found in the half_tbl array */
+			return true;	/* found in the half_tbl array */
 		}
 	}
 
 	/* not found in the half_tbl array */
-	return FALSE;
+	return false;
 }
 
 
@@ -281,6 +288,13 @@ is_const(HALF* h)
 void
 freeh(HALF *h)
 {
+	/* firewall */
+	if (h == NULL) {
+		math_error("%s: h NULL", __func__);
+		not_reached();
+	}
+
+	/* free h is not a constant */
 	if (!is_const(h)) {
 		free(h);
 		++nfree;
@@ -305,6 +319,12 @@ itoz(long i, ZVALUE *res)
 {
 	long diddle, len;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	res->len = 1;
 	res->sign = 0;
 	diddle = 0;
@@ -359,6 +379,12 @@ utoz(FULL i, ZVALUE *res)
 {
 	long len;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	res->len = 1;
 	res->sign = 0;
 	if (i == 0) {
@@ -386,6 +412,12 @@ stoz(SFULL i, ZVALUE *res)
 {
 	long diddle, len;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	res->len = 1;
 	res->sign = 0;
 	diddle = 0;
@@ -470,6 +502,13 @@ ztos(ZVALUE z)
 void
 zcopy(ZVALUE z, ZVALUE *res)
 {
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
+	/* make copy */
 	res->sign = z.sign;
 	res->len = z.len;
 	if (zisabsleone(z)) {	/* zero or plus or minus one are easy */
@@ -493,6 +532,12 @@ zadd(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	FULL carry;
 	SIUNION sival;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (z1.sign && !z2.sign) {
 		z1.sign = 0;
 		zsub(z2, z1, res);
@@ -546,6 +591,12 @@ zsub(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	SIUNION sival;
 	ZVALUE dest;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (z1.sign != z2.sign) {
 		z2.sign = z1.sign;
 		zadd(z1, z2, res);
@@ -616,6 +667,12 @@ zmuli(ZVALUE z, long n, ZVALUE *res)
 	SIUNION sival;
 	ZVALUE dest;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if ((n == 0) || ziszero(z)) {
 		*res = _zero_;
 		return;
@@ -694,6 +751,16 @@ zreduce(ZVALUE z1, ZVALUE z2, ZVALUE *z1res, ZVALUE *z2res)
 {
 	ZVALUE tmp;
 
+	/* firewall */
+	if (z1res == NULL) {
+		math_error("%s: z1res NULL", __func__);
+		not_reached();
+	}
+	if (z2res == NULL) {
+		math_error("%s: z2res NULL", __func__);
+		not_reached();
+	}
+
 	if (zisabsleone(z1) || zisabsleone(z2))
 		tmp = _one_;
 	else
@@ -722,10 +789,20 @@ zdiv(ZVALUE z1, ZVALUE z2, ZVALUE *quo, ZVALUE *rem, long rnd)
 	HALF s, u;
 	HALF *A, *B, *a1, *b0;
 	FULL f, g, h, x;
-	BOOL adjust, onebit;
+	bool adjust, onebit;
 	LEN m, n, len, i, p, j1, j2, k;
 	long t, val;
 
+	/* firewall */
+	if (quo == NULL) {
+		math_error("%s: quo NULL", __func__);
+		not_reached();
+	}
+	if (rem == NULL) {
+		math_error("%s: rem NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z2)) {
 		math_error("Division by zero in zdiv");
 		not_reached();
@@ -782,7 +859,7 @@ zdiv(ZVALUE z1, ZVALUE z2, ZVALUE *quo, ZVALUE *rem, long rnd)
 	j1 = BASEB - k;
 	j2 = BASEB + j1;
 	h = j1 ? ((FULL) B[n - 1] << j1 | B[n - 2] >> k) : B[n-1];
-	onebit = (BOOL)((B[n - 2] >> (k - 1)) & 1);
+	onebit = (bool)((B[n - 2] >> (k - 1)) & 1);
 	m++;
 	while (m > n) {
 		m--;
@@ -837,9 +914,9 @@ done:	while (m > 0 && A[m - 1] == 0)
 		return val;
 	}
 	if (rnd & 8)
-		adjust = (((*a1 ^ rnd) & 1) ? TRUE : FALSE);
+		adjust = (((*a1 ^ rnd) & 1) ? true : false);
 	else
-		adjust = (((rnd & 1) ^ z1.sign ^ z2.sign) ? TRUE : FALSE);
+		adjust = (((rnd & 1) ^ z1.sign ^ z2.sign) ? true : false);
 	if (rnd & 2)
 		adjust ^= z1.sign ^ z2.sign;
 	if (rnd & 4)
@@ -958,6 +1035,12 @@ zquo(ZVALUE z1, ZVALUE z2, ZVALUE *res, long rnd)
 	ZVALUE tmp;
 	long val;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	val = zdiv(z1, z2, res, &tmp, rnd);
 	if (z2.sign)
 		val = -val;
@@ -977,6 +1060,12 @@ zmod(ZVALUE z1, ZVALUE z2, ZVALUE *res, long rnd)
 	ZVALUE tmp;
 	long val;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	val = zdiv(z1, z2, &tmp, res, rnd);
 	zfree(tmp);
 	return val;
@@ -995,6 +1084,12 @@ zequo(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	HALF *a, *a0, *A, *b, *B, u, v, w, x;
 	FULL f, g;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z1)) {
 		*res = _zero_;
 		return;
@@ -1125,6 +1220,12 @@ zdivi(ZVALUE z, long n, ZVALUE *res)
 	ZVALUE dest;
 	LEN len;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (n == 0) {
 		math_error("Division by zero");
 		not_reached();
@@ -1243,31 +1344,31 @@ zmodi(ZVALUE z, long n)
 
 /*
  * Return whether or not one number exactly divides another one.
- * Returns TRUE if division occurs with no remainder.
+ * Returns true if division occurs with no remainder.
  * z1 is the number to be divided by z2.
  */
 
-BOOL
+bool
 zdivides(ZVALUE z1, ZVALUE z2)
 {
 	LEN i, j, k, m, n;
 	HALF u, v, w, x;
 	HALF *a, *a0, *A, *b, *B, *c, *d;
 	FULL f;
-	BOOL ans;
+	bool ans;
 
-	if (zisunit(z2) || ziszero(z1)) return TRUE;
-	if (ziszero(z2)) return FALSE;
+	if (zisunit(z2) || ziszero(z1)) return true;
+	if (ziszero(z2)) return false;
 
 	m = z1.len;
 	n = z2.len;
-	if (m < n) return FALSE;
+	if (m < n) return false;
 
 	c = z1.v;
 	d = z2.v;
 
 	while (!*d) {
-		if (*c++) return FALSE;
+		if (*c++) return false;
 		d++;
 		m--;
 		n--;
@@ -1277,20 +1378,20 @@ zdivides(ZVALUE z1, ZVALUE z2)
 	u = *c;
 	v = *d;
 	while (!(v & 1)) {	/* Counting and checking zero bits */
-		if (u & 1) return FALSE;
+		if (u & 1) return false;
 		u >>= 1;
 		v >>= 1;
 		j++;
 	}
 
-	if (n == 1 && v == 1) return TRUE;
+	if (n == 1 && v == 1) return true;
 	if (!*c) {			/* Removing any further zeros */
 		while(!*++c)
 			m--;
 		c--;
 	}
 
-	if (m < n) return FALSE;
+	if (m < n) return false;
 
 	if (j) {
 		B = alloc((LEN)n);	/* Array for shifted z2 */
@@ -1347,11 +1448,11 @@ zdivides(ZVALUE z1, ZVALUE z2)
 		}
 		a0++;
 	}
-	ans = FALSE;
+	ans = false;
 	if (A[m + 1]) {
 		a = A + m;
 		while (--n && !*--a);
-		if (!n) ans = TRUE;
+		if (!n) ans = true;
 	}
 	freeh(A);
 	if (j) freeh(B);
@@ -1369,6 +1470,12 @@ zor(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	long len;
 	ZVALUE bz, lz, dest;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (z1.len >= z2.len) {
 		bz = z1;
 		lz = z2;
@@ -1399,6 +1506,12 @@ zand(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	LEN len;
 	ZVALUE dest;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	len = ((z1.len <= z2.len) ? z1.len : z2.len);
 	h1 = &z1.v[len-1];
 	h2 = &z2.v[len-1];
@@ -1429,6 +1542,12 @@ zxor(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	LEN len, j, k;
 	ZVALUE dest;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	h1 = z1.v;
 	h2 = z2.v;
 	len = z1.len;
@@ -1466,6 +1585,12 @@ zandnot(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	LEN len, j, k;
 	ZVALUE dest;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	len = z1.len;
 	if (z2.len >= len) {
 		while (len > 1 && (z1.v[len-1] & ~z2.v[len-1]) == 0)
@@ -1501,6 +1626,12 @@ zshift(ZVALUE z, long n, ZVALUE *res)
 	ZVALUE ans;
 	LEN hc;		/* number of halfwords shift is by */
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z)) {
 		*res = _zero_;
 		return;
@@ -1627,37 +1758,37 @@ zhighbit(ZVALUE z)
  * Return whether or not the specified bit number is set in a number.
  * Rightmost bit of a number is bit 0.
  */
-BOOL
+bool
 zisset(ZVALUE z, long n)
 {
 	if ((n < 0) || ((n / BASEB) >= z.len))
-		return FALSE;
+		return false;
 	return ((z.v[n / BASEB] & (((HALF) 1) << (n % BASEB))) != 0);
 }
 
 
 /*
  * Check whether or not a number has exactly one bit set, and
- * thus is an exact power of two.  Returns TRUE if so.
+ * thus is an exact power of two.  Returns true if so.
  */
-BOOL
+bool
 zisonebit(ZVALUE z)
 {
 	register HALF *hp;
 	register LEN len;
 
 	if (ziszero(z) || zisneg(z))
-		return FALSE;
+		return false;
 	hp = z.v;
 	len = z.len;
 	while (len > 4) {
 		len -= 4;
 		if (*hp++ || *hp++ || *hp++ || *hp++)
-			return FALSE;
+			return false;
 	}
 	while (--len > 0) {
 		if (*hp++)
-			return FALSE;
+			return false;
 	}
 	return ((*hp & -*hp) == *hp);		/* NEEDS 2'S COMPLEMENT */
 }
@@ -1666,9 +1797,9 @@ zisonebit(ZVALUE z)
 /*
  * Check whether or not a number has all of its bits set below some
  * bit position, and thus is one less than an exact power of two.
- * Returns TRUE if so.
+ * Returns true if so.
  */
-BOOL
+bool
 zisallbits(ZVALUE z)
 {
 	register HALF *hp;
@@ -1676,18 +1807,18 @@ zisallbits(ZVALUE z)
 	HALF digit;
 
 	if (ziszero(z) || zisneg(z))
-		return FALSE;
+		return false;
 	hp = z.v;
 	len = z.len;
 	while (len > 4) {
 		len -= 4;
 		if ((*hp++ != BASE1) || (*hp++ != BASE1) ||
 			(*hp++ != BASE1) || (*hp++ != BASE1))
-				return FALSE;
+				return false;
 	}
 	while (--len > 0) {
 		if (*hp++ != BASE1)
-			return FALSE;
+			return false;
 	}
 	digit = (HALF)(*hp + 1);
 	return ((digit & -digit) == digit);	/* NEEDS 2'S COMPLEMENT */
@@ -1704,6 +1835,12 @@ zbitvalue(long n, ZVALUE *res)
 {
 	ZVALUE z;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (n < 0) n = 0;
 	z.sign = 0;
 	z.len = (LEN)((n / BASEB) + 1);
@@ -1802,24 +1939,24 @@ zabsrel(ZVALUE z1, ZVALUE z2)
 
 /*
  * Compare two numbers to see if they are equal or not.
- * Returns TRUE if they differ.
+ * Returns true if they differ.
  */
-BOOL
+bool
 zcmp(ZVALUE z1, ZVALUE z2)
 {
 	register HALF *h1, *h2;
 	register long len;
 
 	if ((z1.sign != z2.sign) || (z1.len != z2.len) || (*z1.v != *z2.v))
-		return TRUE;
+		return true;
 	len = z1.len;
 	h1 = z1.v;
 	h2 = z2.v;
 	while (--len > 0) {
 		if (*++h1 != *++h2)
-			return TRUE;
+			return true;
 	}
-	return FALSE;
+	return false;
 }
 
 
@@ -1865,6 +2002,12 @@ ztrim(ZVALUE *z)
 	HALF *h;
 	LEN len;
 
+	/* firewall */
+	if (z == NULL) {
+		math_error("%s: z NULL", __func__);
+		not_reached();
+	}
+
 	h = z->v + z->len - 1;
 	len = z->len;
 	while (*h == 0 && len > 1) {
