@@ -1,7 +1,7 @@
 /*
  * zmod - modulo arithmetic routines
  *
- * Copyright (C) 1999-2007,2021,2022  David I. Bell, Landon Curt Noll and Ernest Bowen
+ * Copyright (C) 1999-2007,2021-2023  David I. Bell, Landon Curt Noll and Ernest Bowen
  *
  * Primary author:  David I. Bell
  *
@@ -41,7 +41,7 @@
 #include "zmath.h"
 
 
-#include "attribute.h"
+#include "errtbl.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -54,7 +54,7 @@ S_FUNC void zredcmodinv(ZVALUE z1, ZVALUE *res);
 
 STATIC REDC *powermodredc = NULL;	/* REDC info for raising to power */
 
-BOOL havelastmod = FALSE;
+bool havelastmod = false;
 STATIC ZVALUE lastmod[1];
 STATIC ZVALUE lastmodinv[1];
 
@@ -76,6 +76,12 @@ zsquaremod(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	FULL prod;
 	FULL digit;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z2) || zisneg(z2)) {
 		math_error("Mod of non-positive integer");
 		not_reached();
@@ -138,6 +144,12 @@ zminmod(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	int sign;
 	int cv;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z2) || zisneg(z2)) {
 		math_error("Mod of non-positive integer");
 		not_reached();
@@ -177,7 +189,7 @@ zminmod(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	}
 	tmp1 = z1;
 	if (cv > 0) {
-		z1.sign = (BOOL)sign;
+		z1.sign = (bool)sign;
 		zmod(z1, z2, &tmp1, 0);
 		if (tmp1.len < z2.len - 1) {
 			*res = tmp1;
@@ -197,7 +209,7 @@ zminmod(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	cv = zrel(tmp1, tmp2);
 	if (cv < 0) {
 		zfree(tmp2);
-		tmp1.sign = (BOOL)sign;
+		tmp1.sign = (bool)sign;
 		if (tmp1.v == z1.v)
 			zcopy(tmp1, res);
 		else
@@ -215,7 +227,7 @@ zminmod(ZVALUE z1, ZVALUE z2, ZVALUE *res)
 /*
  * Compare two numbers for equality modulo a third number.
  * The two numbers to be compared can be negative or out of modulo range.
- * Returns TRUE if the numbers are not congruent, and FALSE if they are
+ * Returns true if the numbers are not congruent, and false if they are
  * congruent.
  *
  * given:
@@ -223,7 +235,7 @@ zminmod(ZVALUE z1, ZVALUE z2, ZVALUE *res)
  *	z2		second number to be compared
  *	z3		modulus
  */
-BOOL
+bool
 zcmpmod(ZVALUE z1, ZVALUE z2, ZVALUE z3)
 {
 	ZVALUE tmp1, tmp2, tmp3;
@@ -243,7 +255,7 @@ zcmpmod(ZVALUE z1, ZVALUE z2, ZVALUE z3)
 	 */
 	if ((z1.sign == z2.sign) && (z1.len == z2.len) &&
 		(z1.v[0] == z2.v[0]) && (zcmp(z1, z2) == 0))
-			return FALSE;
+			return false;
 
 	/*
 	 * If both numbers are negative, then we can make them positive.
@@ -279,7 +291,7 @@ zcmpmod(ZVALUE z1, ZVALUE z2, ZVALUE z3)
 			zfree(tmp1);
 		if (tmp2.v != z2.v)
 			zfree(tmp2);
-		return FALSE;
+		return false;
 	}
 
 	/*
@@ -293,7 +305,7 @@ zcmpmod(ZVALUE z1, ZVALUE z2, ZVALUE z3)
 			zfree(tmp1);
 		if (tmp2.v != z2.v)
 			zfree(tmp2);
-		return TRUE;
+		return true;
 	}
 
 	/*
@@ -315,11 +327,11 @@ zcmpmod(ZVALUE z1, ZVALUE z2, ZVALUE z3)
 	cv = zrel(tmp3, z3);
 	if (cv == 0) {
 		zfree(tmp3);
-		return FALSE;
+		return false;
 	}
 	if (cv < 0) {
 		zfree(tmp3);
-		return TRUE;
+		return true;
 	}
 
 	/*
@@ -330,10 +342,10 @@ zcmpmod(ZVALUE z1, ZVALUE z2, ZVALUE z3)
 	zfree(tmp3);
 	if (ziszero(tmp1)) {
 		zfree(tmp1);
-		return FALSE;
+		return false;
 	} else {
 		zfree(tmp1);
-		return TRUE;
+		return true;
 	}
 }
 
@@ -353,6 +365,12 @@ zmod5(ZVALUE *zp)
 	FULL f;
 	HALF u;
 
+	/* firewall */
+	if (zp == NULL) {
+		math_error("%s: zp NULL", __func__);
+		not_reached();
+	}
+
 	int subcount = 0;
 
 	if (zrel(*zp, *lastmod) < 0)
@@ -431,6 +449,12 @@ zmod6(ZVALUE z1, ZVALUE *res)
 	int sign;
 	ZVALUE zp0, ztmp;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z1) || zisone(*lastmod)) {
 		*res = _zero_;
 		return;
@@ -494,9 +518,15 @@ zpowermod(ZVALUE z1, ZVALUE z2, ZVALUE z3, ZVALUE *res)
 	HALF curhalf;		/* current word of power */
 	unsigned int curpow;	/* current low power */
 	unsigned int curbit;	/* current bit of low power */
-	BOOL free_z1;		/* TRUE => need to free z1 */
+	bool free_z1;		/* true => need to free z1 */
 	int i;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (zisneg(z3) || ziszero(z3)) {
 		math_error("Non-positive modulus in zpowermod");
 		not_reached();
@@ -537,12 +567,12 @@ zpowermod(ZVALUE z1, ZVALUE z2, ZVALUE z3, ZVALUE *res)
 	 * within the modulo range.  Then check for zero or one specially.
 	 */
 	ztmp.len = 0;
-	free_z1 = FALSE;
+	free_z1 = false;
 	if (zisneg(z1) || zrel(z1, z3) >= 0) {
 		zmod(z1, z3, &ztmp, 0);
 		zfree(z1);
 		z1 = ztmp;
-		free_z1 = TRUE;
+		free_z1 = true;
 	}
 	if (ziszero(z1)) {
 		zfree(z1);
@@ -566,14 +596,14 @@ zpowermod(ZVALUE z1, ZVALUE z2, ZVALUE z3, ZVALUE *res)
 		if (havelastmod && zcmp(z3, *lastmod)) {
 			zfree(*lastmod);
 			zfree(*lastmodinv);
-			havelastmod = FALSE;
+			havelastmod = false;
 		}
 		if (!havelastmod) {
 			zcopy(z3, lastmod);
 			zbitvalue(2 * z3.len * BASEB, &temp);
 			zquo(temp, z3, lastmodinv, 0);
 			zfree(temp);
-			havelastmod = TRUE;
+			havelastmod = true;
 		}
 
 		/* zzz */
@@ -607,7 +637,7 @@ zpowermod(ZVALUE z1, ZVALUE z2, ZVALUE z3, ZVALUE *res)
 			if (pp->v == NULL) {
 				if (curpow & 0x1) {
 					zcopy(z1, &modpow);
-					free_z1 = FALSE;
+					free_z1 = false;
 				} else {
 					modpow = _one_;
 				}
@@ -697,7 +727,7 @@ zpowermod(ZVALUE z1, ZVALUE z2, ZVALUE z3, ZVALUE *res)
 			powermodredc = zredcalloc(z3);
 		rp = powermodredc;
 		zredcencode(rp, z1, &temp);
-		if (free_z1 == TRUE) {
+		if (free_z1 == true) {
 			zfree(z1);
 		}
 		zredcpower(rp, temp, z2, &z1);
@@ -740,7 +770,7 @@ zpowermod(ZVALUE z1, ZVALUE z2, ZVALUE z3, ZVALUE *res)
 		if (pp->v == NULL) {
 			if (curpow & 0x1) {
 				zcopy(z1, &modpow);
-				free_z1 = FALSE;
+				free_z1 = false;
 			} else {
 				modpow = _one_;
 			}
@@ -807,7 +837,7 @@ zpowermod(ZVALUE z1, ZVALUE z2, ZVALUE z3, ZVALUE *res)
 	*res = ans;
 	if (ztmp.len)
 		zfree(ztmp);
-	if (free_z1 == TRUE) {
+	if (free_z1 == true) {
 		zfree(z1);
 	}
 }
@@ -824,6 +854,12 @@ zredcmodinv(ZVALUE z, ZVALUE *res)
 	FULL f;
 	LEN N, i, j, len;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	N = z.len;
 	tmp.sign = 0;
 	tmp.len = N;
@@ -923,6 +959,12 @@ zredcalloc(ZVALUE z1)
 void
 zredcfree(REDC *rp)
 {
+	/* firewall */
+	if (rp == NULL) {
+		math_error("%s: rp NULL", __func__);
+		not_reached();
+	}
+
 	zfree(rp->mod);
 	zfree(rp->inv);
 	zfree(rp->one);
@@ -949,6 +991,16 @@ zredcencode(REDC *rp, ZVALUE z1, ZVALUE *res)
 {
 	ZVALUE tmp1;
 
+	/* firewall */
+	if (rp == NULL) {
+		math_error("%s: rp NULL", __func__);
+		not_reached();
+	}
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	/*
 	 * Confirm or initialize lastmod information when modulus is a
 	 * big number.
@@ -958,14 +1010,14 @@ zredcencode(REDC *rp, ZVALUE z1, ZVALUE *res)
 		if (havelastmod && zcmp(rp->mod, *lastmod)) {
 			zfree(*lastmod);
 			zfree(*lastmodinv);
-			havelastmod = FALSE;
+			havelastmod = false;
 		}
 		if (!havelastmod) {
 			zcopy(rp->mod, lastmod);
 			zbitvalue(2 * rp->len * BASEB, &tmp1);
 			zquo(tmp1, rp->mod, lastmodinv, 0);
 			zfree(tmp1);
-			havelastmod = TRUE;
+			havelastmod = true;
 		}
 	}
 	/*
@@ -1037,6 +1089,16 @@ zredcdecode(REDC *rp, ZVALUE z1, ZVALUE *res)
 	LEN len;
 	FULL f;
 	int sign;
+
+	/* firewall */
+	if (rp == NULL) {
+		math_error("%s: rp NULL", __func__);
+		not_reached();
+	}
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
 	int i, j;
 
 	/*
@@ -1213,6 +1275,16 @@ zredcmul(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	ZVALUE z1tmp, z2tmp;
 	int sign;
 
+	/* firewall */
+	if (rp == NULL) {
+		math_error("%s: rp NULL", __func__);
+		not_reached();
+	}
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	sign = z1.sign ^ z2.sign;
 	z1.sign = 0;
 	z2.sign = 0;
@@ -1511,6 +1583,16 @@ zredcsquare(REDC *rp, ZVALUE z1, ZVALUE *res)
 	FULL f;
 	int i, j;
 
+	/* firewall */
+	if (rp == NULL) {
+		math_error("%s: rp NULL", __func__);
+		not_reached();
+	}
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	ztmp.len = 0;
 	z1.sign = 0;
 	if (zrel(z1, rp->mod) >= 0) {
@@ -1707,6 +1789,16 @@ zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res)
 	int sign;
 	int i;
 
+	/* firewall */
+	if (rp == NULL) {
+		math_error("%s: rp NULL", __func__);
+		not_reached();
+	}
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (zisneg(z2)) {
 		math_error("Negative power in zredcpower");
 		not_reached();
@@ -1987,6 +2079,12 @@ zhnrmod(ZVALUE v, ZVALUE zh, ZVALUE zn, ZVALUE zr, ZVALUE *res)
 	int zrelval;		/* return value of zrel() */
 	int hisone;		/* 1 => h == 1, 0 => h != 1 */
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	/*
 	 * firewall
 	 */
