@@ -1,7 +1,7 @@
 /*
  * zmul - faster than usual multiplying and squaring routines
  *
- * Copyright (C) 1999-2007,2021,2022  David I. Bell
+ * Copyright (C) 1999-2007,2021-2023  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -37,7 +37,7 @@
 #include "zmath.h"
 
 
-#include "attribute.h"
+#include "errtbl.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -144,10 +144,20 @@ domul(HALF *v1, LEN size1, HALF *v2, LEN size2, HALF *ans)
 	FULL carryACBD;		/* carry from addition of A*C and B*D */
 	FULL digit;		/* single digit multiplying by */
 	HALF *temp;		/* base for temporary calculations */
-	BOOL neg;		/* whether intermediate term is negative */
+	bool neg;		/* whether intermediate term is negative */
 	register HALF *hd, *h1=NULL, *h2=NULL;	/* for inner loops */
 	SIUNION sival;		/* for addition of digits */
 
+	/* firewall */
+	if (v1 == NULL) {
+		math_error("%s: v1 NULL", __func__);
+		not_reached();
+	}
+	if (ans == NULL) {
+		math_error("%s: ans NULL", __func__);
+		not_reached();
+	}
+
 	/*
 	 * Trim the numbers of leading zeroes and initialize the
 	 * estimated size of the result.
@@ -401,7 +411,7 @@ domul(HALF *v1, LEN size1, HALF *v2, LEN size2, HALF *ans)
 	 * location at position 0 of the result.  Negate the sign if A is
 	 * smaller than B.
 	 */
-	neg = FALSE;
+	neg = false;
 	if (sizeA == sizeB) {
 		len = sizeA;
 		h1 = &baseA[len - 1];
@@ -651,6 +661,12 @@ zsquare(ZVALUE z, ZVALUE *res)
 {
 	LEN len;
 
+	/* firewall */
+	if (res == NULL) {
+		math_error("%s: res NULL", __func__);
+		not_reached();
+	}
+
 	if (ziszero(z)) {
 		*res = _zero_;
 		return;
@@ -735,6 +751,16 @@ dosquare(HALF *vp, LEN size, HALF *ans)
 	register HALF *hd, *h1, *h2, *h3;	/* for inner loops */
 	SIUNION sival;		/* for addition of digits */
 
+	/* firewall */
+	if (vp == NULL) {
+		math_error("%s: vp NULL", __func__);
+		not_reached();
+	}
+	if (ans == NULL) {
+		math_error("%s: ans NULL", __func__);
+		not_reached();
+	}
+
 	/*
 	 * First trim the number of leading zeroes.
 	 */
